/*!
 * age-gate@0.4.4
 * Build date: Tue Aug 17 2021 17:56:47 GMT+0200 (Central European Summer Time)
 */
/******/ (() => { // webpackBootstrap
/******/ 	var __webpack_modules__ = ({

/***/ 175:
/***/ ((module) => {

/*!
 * NativeBus for PopupWebView
 * Copyright(C) King, 2018
 */

(function()
{
    "use strict";

    var nativeBus = {
        Result: Object.freeze({
            FAILURE: 0,
            SUCCESS: 1
        })
    };

    // Configure window._messageBus used for low-level communication between
    // web page and PopupWebView native implementation.
    var messageBus = {};

    // Unify communication over all platforms.
    if (window._messageBus)
    {
        // Android PopupWebView.
        messageBus = window._messageBus;
    }
    else if (window.webkit && window.webkit.messageHandlers && window.webkit.messageHandlers._messageBus)
    {
        // iOS PopupWebView.
        window._messageBus = messageBus;
        var iOSBus = window.webkit.messageHandlers._messageBus;

        messageBus.postMessage = function(msgName, msgPayload, responseCallbackId)
        {
            iOSBus.postMessage(JSON.stringify({
                name: msgName,
                payload: msgPayload,
                id: responseCallbackId
            }));
        };

        messageBus.sendMessageResponse = function(responseCallbackId, resultValue, respPayload)
        {
            iOSBus.postMessage(JSON.stringify({
                result: resultValue,
                payload: respPayload,
                id: responseCallbackId
            }));
        };
    }
    else if (typeof (window.external) !== "undefined" && "notify" in window.external)
    {
        // window.external.notify is undefined even though you can make calls to it
        // without any issues
        // MS Edge webcontrol
        window._messageBus = messageBus;

        messageBus.postMessage = function(msgName, msgPayload, responseCallbackId)
        {
            window.external.notify(JSON.stringify({
                name: msgName,
                payload: msgPayload,
                id: responseCallbackId
            }));
        };

        messageBus.sendMessageResponse = function(responseCallbackId, resultValue, respPayload)
        {
            window.external.notify(JSON.stringify({
                result: resultValue,
                payload: respPayload,
                id: responseCallbackId
            }));
        };
    }
    else
    {
        // Classic web browser.
        window._messageBus = messageBus;

        messageBus.postMessage = function(msgName, msgPayload, responseCallbackId)
        {
            window.console.log("message [" + msgName + "] sent with [" + msgPayload + "] payload");
            this.onMessageResponse(responseCallbackId, msgName, nativeBus.Result.SUCCESS, null);
        };

        messageBus.sendMessageResponse = function()
        {
            // Empty function.
        };
    }

    // Add messageBus handler for messages received from PopupWebView native implementation.
    var messageListener = null;

    messageBus.onMessageReceived = function(msgName, msgPayload, responseCallbackId)
    {
        var responder = null;
        if ((typeof (responseCallbackId) === "number") && isFinite(responseCallbackId) && (responseCallbackId >= 0))
        {
            var that = this;
            var responseSent = false;
            responder = {
                sendMessageResponse: function(resultValue, respPayload)
                {
                    if (!responseSent)
                    {
                        responseSent = true;

                        if (resultValue !== nativeBus.Result.SUCCESS)
                        {
                            resultValue = nativeBus.Result.FAILURE;
                        }

                        if (typeof (respPayload) === "object")
                        {
                            if (respPayload)
                            {
                                respPayload = JSON.stringify(respPayload);
                            }
                        }
                        else if (typeof (respPayload) !== "string")
                        {
                            respPayload = null;
                        }

                        try
                        {
                            that.sendMessageResponse(responseCallbackId, resultValue, respPayload);
                        }
                        catch (e)
                        {
                            window.console.error("cannot send message response to PopupWebView native implementation (" + e.message + ")");
                        }
                    }
                }
            };
        }

        if (messageListener)
        {
            try
            {
                if (typeof (messageListener) === "function")
                {
                    messageListener(msgName, msgPayload, responder);
                }
                else if (msgName && (typeof (msgName) === "string"))
                {
                    if (typeof (messageListener[msgName]) === "function")
                    {
                        messageListener[msgName](msgPayload, responder);
                    }
                    else if (responder)
                    {
                        responder.sendMessageResponse(nativeBus.Result.FAILURE, "unknown message");
                    }
                }
                else if (responder)
                {
                    responder.sendMessageResponse(nativeBus.Result.FAILURE, "invalid message name");
                }
            }
            catch (e)
            {
                var str = "unexpected error while calling message listener (" + e.message + ")";
                window.console.warn(str);

                if (responder)
                {
                    responder.sendMessageResponse(nativeBus.Result.FAILURE, str);
                }
            }
        }
        else if (responder)
        {
            responder.sendMessageResponse(nativeBus.Result.FAILURE, "unknown message");
        }
    };

    // Add messageBus handler for responses received from PopupWebView native implementation.
    var requestsCB = [];

    messageBus.onMessageResponse = function(responseCallbackId, msgName, resultValue, respPayload)
    {
        if ((typeof (responseCallbackId) === "number") && isFinite(responseCallbackId) &&
            (responseCallbackId >= 0) && (responseCallbackId < requestsCB.length))
        {
            var cb = requestsCB[responseCallbackId];
            requestsCB[responseCallbackId] = null;

            if (typeof (cb) === "function")
            {
                try
                {
                    cb(msgName, resultValue, respPayload);
                }
                catch (e)
                {
                    window.console.warn("unexpected error while calling message response callback (" + e.message + ")");
                }
            }
        }
    };

    // Add nativeBus API setMessageListener(l).
    // Listener l can be:
    // - a simple function called with following arguments l(msgName, msgPayload, responder) when a
    //   message with [msgName] name and [msgPayload] payload is received from PopupWebView native implementation;
    // - an object which keys correspond to listened messages names, then when a message with name [msgName] is
    //   received from PopupWebView native implementation, corresponding listener method is called as
    //   l[msgName](msgPayload, responder).
    // In both cases, [responder] is null (if caller has not specified any response callback), or a valid object with
    // only one method (if caller has specified a response callback). To send response information just call
    // responder.sendMessageResponse(result, respPayload) with [result] one of the values of nativeBus.Result, and
    // [respPayload] the response payload (may be null, a string or a valid object which is automatically encoded
    // in JSON string).
    nativeBus.setMessageListener = function(l)
    {
        if ((typeof (l) === "function") || (typeof (l) === "object"))
        {
            messageListener = l;
        }
        else
        {
            messageListener = null;
        }
    };

    // Add nativeBus API postMessage(msgName, msgPayload, responseCB).
    // [msgName] must be a valid non-empty string or no message will be posted.
    // [msgPayload] may be null, a string or a valid object which is automatically encoded in JSON string.
    // [responseCB] callback may be null or a valid function that will be called as
    // responseCB(msgName, result, respPayload) with [msgName] the message name, [result] one of nativeBus.Result
    // values and [respPayload] the response payload.
    nativeBus.postMessage = function(msgName, msgPayload, responseCB)
    {
        if (msgName && (typeof (msgName) === "string"))
        {
            if (typeof (msgPayload) === "object")
            {
                if (msgPayload)
                {
                    msgPayload = JSON.stringify(msgPayload);
                }
            }
            else if (typeof (msgPayload) !== "string")
            {
                msgPayload = null;
            }

            var id = -1;
            if (typeof (responseCB) === "function")
            {
                var size = requestsCB.length;
                for (id = 0; id < size; ++id)
                {
                    if (!requestsCB[id])
                    {
                        requestsCB[id] = responseCB;
                        break;
                    }
                }

                if (id >= size)
                {
                    requestsCB.push(responseCB);
                }
            }

            try
            {
                messageBus.postMessage(msgName, msgPayload, id);
            }
            catch (e)
            {
                var str = "cannot post message to PopupWebView native implementation (" + e.message + ")";
                window.console.error(str);

                if (id >= 0)
                {
                    requestsCB[id] = null;

                    try
                    {
                        responseCB(msgName, nativeBus.Result.FAILURE, str);
                    }
                    catch (ee)
                    {
                        window.console.warn("unexpected error while calling message response callback (" + ee.message + ")");
                    }
                }
            }
        }
        else if (typeof (responseCB) === "function")
        {
            try
            {
                responseCB(msgName, nativeBus.Result.FAILURE, "invalid null or empty message name");
            }
            catch (e)
            {
                window.console.warn("unexpected error while calling message response callback (" + e.message + ")");
            }
        }
    };

    if (true)
    {
        // Export nativeBus interface for webpack.
        module.exports = nativeBus; // eslint-disable-line
    }
    else
    {}
})();


/***/ }),

/***/ 603:
/***/ ((__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) => {

"use strict";

// EXTERNAL MODULE: ./node_modules/@king/nativeBus/web/nativeBus.js
var nativeBus = __webpack_require__(175);
var nativeBus_default = /*#__PURE__*/__webpack_require__.n(nativeBus);
;// CONCATENATED MODULE: ./node_modules/@king/uv-slayer/dist/uv-slayer.esm.js
/*!
 * @king/uv-slayer v2.10.0
 * Copyright(C) King, 2021 
 */



/* !
 * Object.assign Polyfill from the proposal in MDN web docs:
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/assign#Polyfill
 */

if (typeof Object.assign !== "function") {
  // Must be writable: true, enumerable: false, configurable: true
  Object.defineProperty(Object, "assign", {
    value: function assign(target) {
      // .length of function is 2
      if (target === null || target === undefined) {
        throw new TypeError("Cannot convert undefined or null to object");
      }

      var to = Object(target);

      for (var index = 1; index < arguments.length; index++) {
        var nextSource = arguments[index];

        if (nextSource !== null && nextSource !== undefined) {
          for (var nextKey in nextSource) {
            // Avoid bugs when hasOwnProperty is shadowed
            if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
              to[nextKey] = nextSource[nextKey];
            }
          }
        }
      }

      return to;
    },
    writable: true,
    configurable: true
  });
}

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

/*!
 * @king/uv-core v2.7.0
 * Copyright(C) King, 2021 
 */
/**
 * System Message actions
 */

var SystemMessages = Object.freeze({
  EXIT: "exit",
  SYSTEM_BACK_BUTTON: "systemBackButton",
  GET_SCENE_INFO: "getSceneInfo",
  ERROR: "error",
  TRACK: "track",
  DISABLE_GAME_MUSIC: "mediaStarted",
  ENABLE_GAME_MUSIC: "mediaFinished"
});
var _messagesHooks = {};
var _unknownMessagesHook = null;
/**
 * Default post message using SystemMessages constant
 * @return {boolean} true
 */

function _defaultSystemBackButtonHook() {
  nativeBus_default().postMessage(SystemMessages.EXIT, SystemMessages.SYSTEM_BACK_BUTTON);
  return true;
}

_messagesHooks[SystemMessages.SYSTEM_BACK_BUTTON] = _defaultSystemBackButtonHook;
nativeBus_default().setMessageListener(function (msgName, msgPayload, responder) {
  var hook = _unknownMessagesHook;

  if (msgName && typeof msgName === "string") {
    var entry = _messagesHooks[msgName];

    if (entry) {
      hook = entry;
    }
  }

  if (hook) {
    try {
      var ret = hook(msgName, msgPayload, responder);

      if (ret !== undefined && responder) {
        if (ret === false || ret instanceof Error) {
          var msg = ret && ret.message ? ret.message : "unspecified failure";
          responder.sendMessageResponse((nativeBus_default()).Result.FAILURE, msg);
        } else {
          responder.sendMessageResponse((nativeBus_default()).Result.SUCCESS, ret);
        }
      }
    } catch (e) {
      if (responder) {
        responder.sendMessageResponse((nativeBus_default()).Result.FAILURE, e.message ? e.message : "unspecified failure");
      }
    }
  } else if (responder) {
    responder.sendMessageResponse((nativeBus_default()).Result.FAILURE, "no message hook defined");
  }
});
/**
 * Message result.
 * @enum
 * @public
 * @memberof UVCore
 * @property {number} FAILURE - Message execution has failed (value: 0).
 * @property {number} SUCCESS - Message execution has succeeded (value: 1).
 */

var Result = (nativeBus_default()).Result;
/**
 * System messages.
 * @enum
 * @public
 * @memberof UVCore
 * @property {string} EXIT - System message to send to native application to request web scene termination.
 * Associated payload may be null or a string describing the cause of the termination request.
 * @property {string} SYSTEM_BACK_BUTTON - System message received from native application when user clicks
 * on device back button (if applicable). Associated payload is always null. By default, if no specific hook
 * has been registered to override this message, an <i>EXIT</i> message is posted back to native application
 * with <i>SYSTEM_BACK_BUTTON</i> value as payload.
 * @property {string} GET_SCENE_INFO - System message automatically sent by web scene to native application
 * when DOM content has been loaded. Native application must answer this message with a
 * [NativeAppInfo]{@link UVCore.NativeAppInfo} object.
 */

var Messages = SystemMessages;
/**
 * Prototype of message response callback, called as a response to a posted message.
 * @callback ResponseCB
 * @public
 * @memberof UVCore
 * @param {string} msgName - Name of the message previously posted.
 * @param {UVCore.Result} result - Result of message execution by native application.
 * @param {string} respPayload - Payload of message response, may be null or undefined.
 */

/**
 * Posts a message to native application.
 * @function
 * @public
 * @memberof UVCore
 * @param {string} msgName - Name of the message to post. It must be a valid non-empty string
 * or no message will be posted.
 * @param {string|object} [msgPayload] - Associated message payload. It may be null/undefined,
 * a string, or a valid object (which is automatically encoded into a JSON string).
 * @param {UVCore.ResponseCB} [responseCB] - Response callback called when message has
 * been executed by native application. Pass null or undefined if you are not interested by the
 * response.
 */

var postMessage = (nativeBus_default()).postMessage;
/**
 * Posts an error message.
 * @param {string} errorDescription
 * @param {boolean} terminate
 */

var postError = function postError(errorDescription, terminate) {
  terminate = terminate === undefined ? false : !!terminate;
  nativeBus_default().postMessage(SystemMessages.ERROR, {
    terminate: terminate,
    errorDescription: errorDescription
  });
};
/**
 * Posts track message.
 * All the parameters are converted to string in order to be parsed for the client and tracked correctly.
 * @param {string} [category]  used to group similar events, examples: 'video', 'experiment', 'campaign-name'
 * @param {string} [action]    used to identify what triggers the action, examples:
 *                             'click', 'element-load', 'show', 'video-play', 'video-pause'
 * @param {string} [label]     indicates the element that triggers the action, examples:
 *                             'play-button', 'hero-video', 'close-button'
 * @param {string} [value]     A value that can be anything somehow related to the tracked event, can be a timer,
 *                             indicate a selection on a combo box, etc. examples: 1000, monkey, opt-out.
 */


var postTrack = function postTrack(category, action, label, value) {
  category = category === undefined ? "" : category.toString();
  action = action === undefined ? "" : action.toString();
  label = label === undefined ? "" : label.toString();
  value = value === undefined ? "" : value.toString();
  nativeBus_default().postMessage(SystemMessages.TRACK, {
    category: category,
    requestAction: action,
    label: label,
    requestValue: value
  });
};

var disableGameMusic = function disableGameMusic() {
  nativeBus_default().postMessage(SystemMessages.DISABLE_GAME_MUSIC);
};

var enableGameMusic = function enableGameMusic() {
  nativeBus_default().postMessage(SystemMessages.ENABLE_GAME_MUSIC);
};
/**
 * Workaround in order to solve the problem with webkit repaint process
 * and the propagation of the style changes. In low-end devices, some
 * animations are not finishing correctly because the webview does
 * not refresh the content correctly. This forces the repaint
 * process and all is repainted again, and positioned well.
 * @see: https://stackoverflow.com/questions/3485365/how-can-i-force-webkit-to-redraw-repaint-to-propagate-style-changes
 * @see: http://thenewcode.com/1024/Forcing-a-Webkit-Repaint
 */


var forceRepaint = function forceRepaint() {
  setTimeout(function () {
    document.body.style.transform = "translateZ(0)";
  }, 1000);
};
/**
 * This interface is used to send back an asynchronous response to native application when receiving
 * a message.
 * @interface Responder
 * @public
 * @memberof UVCore
 */

/**
 * Sends a message response to native application.
 * @method UVCore.Responder#sendMessageResponse
 * @public
 * @param {UVCore.Result} [result=Result.FAILURE] - Result of message execution. If not
 * specified or invalid, default value is [Result.FAILURE]{@link UVCore.Result}.
 * @param {string|object} [respPayload] - Response payload. It may be null/undefined,
 * a string, or a valid object (which is automatically encoded into a JSON string).
 */

/**
 * Prototype of messages hook function called whenever registered messages are received from
 * native application.
 * <p>Web page can (or must) send a response to native application:</p>
 * <ul>
 *   <li>
 *     by calling
 *     [responder.sendMessageResponse(result, respPayload)]{@link UVCore.Responder.sendMessageResponse}
 *     in order to send back a response synchronously or asynchronously,
 *   </li>
 *   <li>
 *     by directly returning a value:
 *     <ul>
 *       <li>
 *         <i>false</i> or any <i>Error</i> instance will send a failed response immediately,
 *       </li>
 *       <li>
 *         any other value will send a success response immediately (if value is a string or
 *         a valid object, it will be passed as response payload just like when calling
 *         [responder.sendMessageResponse(
 *              Result.SUCCESS, returnedValue)]{@link UVCore.Responder.sendMessageResponse}),
 *       </li>
 *     </ul>
 *   </li>
 *   <li>
 *     by throwing out any <i>Error</i> instance, then a failed response is sent immediately.
 *   </li>
 * </ul>
 * <p>
 *   <b>WARNING</b>: if using <i>responder</i> interface to send a response asynchronously, take
 *   special care to return nothing or undefined from <i>MessageHook</i> function as only the first
 *   response is sent to native application.
 * </p>
 * <p>
 *   <b>WARNING</b>: if ignoring <i>responder</i> interface in <i>MessageHook</i> function because
 *   you are always sending the response synchronously, take special care to at least return
 *   <i>true</i> (or <i>false</i>) in order to always send a response whenever native application
 *   expects one.
 * </p>
 * @callback MessageHook
 * @public
 * @memberof UVCore
 * @param {string} msgName - Name of the received message.
 * @param {string} msgPayload - Associated message payload, may be null or undefined.
 * @param {UVCore.Responder} responder - Responder interface used to send back a
 * response to native application. This parameter may be null if caller has not specified any
 * response callback when sending the message.
 * <p>
 *   <b>WARNING</b>: If <i>responder</i> is different from null, you <b>MUST</b> send back a response.
 * </p>
 * @returns {undefined|boolean|Error|string|object} If using <i>responder</i> interface to send
 * a response (synchronously or asynchronously), just return <i>undefined</i> (or nothing). If
 * sending a response synchronously (without using <i>responder</i>), return a boolean value
 * (<i>false</i> is interpreted as a failure), an <i>Error</i> instance (also interpreted as a
 * failure); or any string or valid object that will be passed as response payload (interpreted as
 * a success).
 * @throws If throwing out any <i>Error</i> instance, the response is sent immediately and is
 * interpreted as a failure.
 */

/**
 * Sets a message hook function for a specific message.
 * @function
 * @public
 * @memberof UVCore
 * @param {string} msgName - Name of the message for which hook will be set. If not a string,
 * or an empty string, hook will be set for all messages without a specific hook.
 * @param {UVCore.MessageHook} hook - Hook function, pass null to remove a previous hook.
 * In case of [Message.SYSTEM_BACK_BUTTON]{@link UVCore.Message} hook, passing null will
 * restore the default behavior.
 */


var setMessageHook = function setMessageHook(msgName, hook) {
  if (msgName && typeof msgName === "string") {
    if (typeof hook === "function") {
      _messagesHooks[msgName] = hook;
    } else if (msgName === SystemMessages.SYSTEM_BACK_BUTTON) {
      _messagesHooks[msgName] = _defaultSystemBackButtonHook;
    } else {
      delete _messagesHooks[msgName];
    }
  } else if (typeof hook === "function") {
    _unknownMessagesHook = hook;
  } else {
    _unknownMessagesHook = null;
  }
};

var comChannel = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Result: Result,
  Messages: Messages,
  postMessage: postMessage,
  postError: postError,
  postTrack: postTrack,
  disableGameMusic: disableGameMusic,
  enableGameMusic: enableGameMusic,
  forceRepaint: forceRepaint,
  setMessageHook: setMessageHook
});
/* eslint-disable require-jsdoc */

function handleUncaughtErrors(message, source, lineno, colno, error) {
  var errorInfo = {
    message: message,
    url: source,
    line: lineno || 1,
    column: colno || 1,
    error: error
  };
  postError(JSON.stringify(errorInfo));
}

window.onerror = handleUncaughtErrors;

var constants = {
  TOUCHED_CLASS_NAME: "uv-touched",
  Messages: {
    CLOSE: "SL_CLOSE",
    ACTION: "ACTION",
    SKIP: "SKIP",
    CTA_BUTTON: "BUTTON"
  }
};

/**
 * Private function to add a touched class to the node passed in parameter.
 * @param {any} node Node to add the class to
 * @param {string} editionType Type of edition performed
 */

function addTouchedClass(node, editionType) {
  if (!!node && "classList" in node) {
    node.classList.add(constants.TOUCHED_CLASS_NAME);
    node.classList.add(constants.TOUCHED_CLASS_NAME + "-" + editionType);
  }
}
/**
 * Override content
 *
 * @param {array} overridesList
 * @param {Document} dom
 * @return {any} Structure of all replaced objects {"id": "value", "id2": "values"}
 */


function overrideNodes(overridesList, dom) {
  // @see https://github.int.midasplayer.com/GamePlatform/game-platform/blob/0d9755ff9cedab6341545dfc944529a300b4c3d9/packages/base-sdk/servicelayer/source/common/unified_views/View.cpp#L407
  var regBackground = /background:\s?url\("?([^"]*)"?\);?/im;
  var replacements = {
    translations: {},
    styles: {},
    attributes: {}
  };

  for (var selector in overridesList) {
    if (!Object.prototype.hasOwnProperty.call(overridesList, selector)) {
      continue;
    }

    var overrides = overridesList[selector];

    if (!overrides || _typeof(overrides) !== "object") {
      continue;
    }

    var isAttribute = overrides.attributes && _typeof(overrides.attributes) === "object";
    var isStyle = overrides.style && typeof overrides.style === "string";
    var isTranslation = overrides.innerHTML && typeof overrides.innerHTML === "string";

    if (isAttribute) {
      replacements.attributes[selector] = overrides.attributes;
    }

    if (isStyle) {
      replacements.styles[selector] = overrides.style;
    }

    if (isTranslation) {
      replacements.translations[selector] = overrides.innerHTML;
    }

    try {
      var nodes = dom.querySelectorAll(selector);

      for (var i = nodes.length - 1; i >= 0; --i) {
        var node = nodes[i];

        try {
          if (isTranslation) {
            // To check if the node has the class lets to the HTML creator to control
            // which nodes can be updated. Otherwise, the code cannot be robust.
            if (node.classList.contains("html-placeholder")) {
              node.innerHTML = overrides.innerHTML;
              addTouchedClass(node, "html");
            }
          }

          if (isAttribute) {
            // Since we protect innerHTML with a class, this attribute can not be
            // modified as an attribute. So if exists, we delete it from attributes.
            if (Object.hasOwnProperty.call(overrides.attributes, "innerHTML")) {
              delete overrides.attributes.innerHTML;
            }

            Object.assign(node, overrides.attributes);
            addTouchedClass(node, "attr");
          }

          if (isStyle && node.style) {
            // Special case for images and background. If the style
            // is a background, should be setted as src attribute
            // within the image and delete it from the style.
            if (node.nodeName.toLowerCase() === "img") {
              var matches = regBackground.exec(overrides.style);

              if (matches !== null && matches.length) {
                node.src = matches[1];
                overrides.style = overrides.style.replace(matches[0], "");
              }
            }

            node.style.cssText += overrides.style;
            addTouchedClass(node, "style");
          }
        } catch (e) {
          window.console.warn("cannot override HTML-element attributes (" + e.message + ")");
        }
      }
    } catch (ee) {
      window.console.warn("cannot select HTML-elements to override (" + ee.message + ")");
    }
  }

  return replacements;
}
/**
 * Dispatch Event
 * @param {uvbootstrap.NativeAppInfo} nativeAppInfo - Native application information.
 */


function dispatchNativeAppEvent(nativeAppInfo) {
  // We cannot use the modern version of the event API (i.e. new CustomEvent(...))
  // because it is not supported on iOS < 11.3 whereas the legacy version is
  // supported everywhere.
  var event = document.createEvent("CustomEvent");
  event.initCustomEvent("NativeAppReady", false, false, nativeAppInfo);
  document.dispatchEvent(event);
}
/**
 * Set viewport configuration.
 *
 * @param {Document} document
 * @return {HTMLElement} viewport
 */


function getOrAddViewportTag(document) {
  var metaTags = document.head.getElementsByTagName("meta");
  var viewportTag = null;

  for (var i = metaTags.length - 1; i >= 0; --i) {
    var tag = metaTags[i];

    if (tag.name === "viewport") {
      if (viewportTag) {
        tag.parentNode.removeChild(tag);
      } else {
        viewportTag = tag;
      }
    }
  }

  if (!viewportTag) {
    viewportTag = document.createElement("meta");
    viewportTag.name = "viewport";
    document.head.appendChild(viewportTag);
  }

  return viewportTag;
}

/**
 * UnifiedViews Bootstrap
 * Copyright(C) King, 2018
 */
/**
 * Native application information.
 * @interface NativeAppInfo
 * @public
 * @memberof uvbootstrap
 * @property {boolean} loaded - True if information has already been loaded from native
 * application, or false if not. In the latter case, you can add an event listener on document
 * for [NativeAppReady]{@link uvbootstrap.event:NativeAppReady} event in order to get
 * information as soon as it is loaded.
 * @property {boolean} success - True if information from native application has been fetched
 * with success, or false if not.
 * @property {number} userId - Native application user ID.
 * @property {string} installId - Native application installation ID.
 * @property {string} funnelId - Native application funnel ID.
 * @property {string} language - Native application language.
 * @property {string} adId - Native application advertisement ID.
 * @property {string} sessionKey - Native application session key.
 * @property {number} appId - Native application id.
 * @property {number} timestamp - Client time (in seconds since epoch).
 * @property {boolean} forced - Native forced flag. True if the web page should hide any close button.
 * @property {boolean} shouldPlayAudio - Native flag to know if the view should play audio effects or not
 */

var _defaultNativeAppInfo = Object.freeze({
  loaded: false,
  success: false,
  userId: 0,
  installId: "",
  funnelId: "",
  language: "",
  adId: "",
  sessionKey: "",
  appId: 0,
  timestamp: 0,
  forced: false,
  shouldPlayAudio: true,
  replacements: {
    translations: {},
    styles: {},
    attributes: {}
  }
}); //
// Configure native application information and overrides.
//


var _nativeAppInfo = _defaultNativeAppInfo;
/**
 * Event emitted on document when native application is ready.
 * <p>This event is dispatched on the document node when native application has
 * finished initializing the web page and has transmitted all native
 * information.</p>
 * <p>If you need to process native application information during web scene
 * initialization, just add a listener for the event like this:
 * <pre>
 * document.addEventListener("NativeAppReady", function(e)
 * {
 *     if (e.detail.success)
 *     {
 *         ...
 *     }
 * }
 * </pre></p>
 * @event NativeAppReady
 * @public
 * @memberof uvbootstrap
 * @mixes CustomEvent
 * @property {uvbootstrap.NativeAppInfo} detail - Native application information.
 */
// eslint-disable-next-line max-len

getOrAddViewportTag(document).content = "width=device-width, shrink-to-fit=no, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0, user-scalable=no, viewport-fit=cover";
/**
 * Function used as callback for postMessage in order to
 * replace the view content by the service layer and
 * to get the NativeAppInfo, that it iss passed
 * throught the NativeAppReady custom event.
 *
 * @param {*} name
 * @param {*} result
 * @param {*} payload
 */

function onGetInfoSceneCallback(name, result, payload) {
  var data = {}; // TODO: check if payload is an object

  if (payload && typeof payload === "string") {
    try {
      data = JSON.parse(payload);
    } catch (e) {
      window.console.warn("cannot decode information received from native application (" + e.message + ")");
    }

    if (!data || _typeof(data) !== "object") {
      data = {};
    }
  } // Override view content


  if (data.overrides) {
    if (_typeof(data.overrides) === "object") {
      data.translations = overrideNodes(data.overrides, document);
    }

    delete data.overrides;
  } // Set info


  data.loaded = true;
  data.success = result === comChannel.Result.SUCCESS;
  _nativeAppInfo = Object.freeze(Object.assign({}, _defaultNativeAppInfo, data)); // Set the language

  document.documentElement.setAttribute("lang", _nativeAppInfo.language); // Dispatch "NativeAppReady"

  dispatchNativeAppEvent(_nativeAppInfo);
}
/**
 * DOM Content loaded listener
 */


document.addEventListener("DOMContentLoaded", function () {
  // Let's fetch overrides on next execution loop in order to be sure
  // that any DOM modification done by web scene has been executed before.
  window.setTimeout(function () {
    comChannel.postMessage(comChannel.Messages.GET_SCENE_INFO, null, onGetInfoSceneCallback);
  }, 0);
});



// EXTERNAL MODULE: ./node_modules/dayjs/dayjs.min.js
var dayjs_min = __webpack_require__(484);
var dayjs_min_default = /*#__PURE__*/__webpack_require__.n(dayjs_min);
;// CONCATENATED MODULE: ./src/assets/img/restricted.png
/* harmony default export */ const restricted = (__webpack_require__.p + "assets/img/restricted.png");
;// CONCATENATED MODULE: ./src/assets/img/generic.png
/* harmony default export */ const generic = (__webpack_require__.p + "assets/img/generic.png");
// EXTERNAL MODULE: ./src/utils/fixFixed.js
var fixFixed = __webpack_require__(753);
// EXTERNAL MODULE: ./src/utils/fixViewport.js
var fixViewport = __webpack_require__(540);
// EXTERNAL MODULE: ./src/utils/fixMonthInput.js
var fixMonthInput = __webpack_require__(653);
;// CONCATENATED MODULE: ./src/utils/toArray.js
var toArray = function toArray(arrayLike) {
  return Array.prototype.slice.call(arrayLike);
};
;// CONCATENATED MODULE: ./src/utils/debounce.js
/**
 * Debounce function from https://levelup.gitconnected.com/debounce-in-javascript-improve-your-applications-performance-5b01855e086
 */
var DEBOUNCE_TIME = 1000;
var debounce = function debounce(func) {
  var wait = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEBOUNCE_TIME;
  var timeout;
  return function executedFunction() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var later = function later() {
      clearTimeout(timeout);
      func.apply(void 0, args);
    };

    clearTimeout(timeout);
    timeout = setTimeout(later, wait);
  };
};
;// CONCATENATED MODULE: ./src/i18n/lang-mapping.json
const lang_mapping_namespaceObject = JSON.parse('{"en":"en","es":"es","es-es":"es","ca":"es","eu":"es","gl":"es","ca-es":"es","eu-es":"es","gl-es":"es","ca_es":"es","eu_es":"es","gl_es":"es","es-ar":"es_MX","es-bo":"es_MX","es-cl":"es_MX","es-co":"es_MX","es-cr":"es_MX","es-do":"es_MX","es-ec":"es_MX","es-sv":"es_MX","es-gt":"es_MX","es-hn":"es_MX","es-mx":"es_MX","es-ni":"es_MX","es-pa":"es_MX","es-py":"es_MX","es-pe":"es_MX","es-pr":"es_MX","es-us":"es_MX","es-uy":"es_MX","es-419":"es_MX","es-xl":"es_MX","es_ar":"es_MX","es_bo":"es_MX","es_cl":"es_MX","es_co":"es_MX","es_cr":"es_MX","es_do":"es_MX","es_ec":"es_MX","es_sv":"es_MX","es_gt":"es_MX","es_hn":"es_MX","es_mx":"es_MX","es_ni":"es_MX","es_pa":"es_MX","es_py":"es_MX","es_pe":"es_MX","es_pr":"es_MX","es_us":"es_MX","es_uy":"es_MX","es_419":"es_MX","es_xl":"es_MX","tr":"tr","it":"it","it-it":"it","it_it":"it","no":"no","nb":"no","nb-no":"no","nb_no":"no","nn":"no","fr":"fr","de":"de","da":"da","sv":"sv","fi":"fi","nl":"nl","cs":"cs","hr":"hr","hu":"hu","pl":"pl","ro":"ro","ru":"ru","sk":"sk","pt":"pt_BR","pt-br":"pt_BR","pt-pt":"pt_BR","pt_br":"pt_BR","pt_pt":"pt_BR","ja":"ja","ko":"ko","th":"th","vi":"vi","zh-hans":"zh_CN","zh_hans":"zh_CN","zh-cn":"zh_CN","zh_cn":"zh_CN","zh":"zh","zh-hant":"zh","zh_hant":"zh","zh-tw":"zh","zh_tw":"zh","zh-hk":"zh","zh_hk":"zh","zh-sg":"zh","zh_sg":"zh","zh-mo":"zh","zh_mo":"zh","zh-tw_tw":"zh","zh-tw-tw":"zh","zh-hk_hk":"zh","zh-hk-hk":"zh"}');
;// CONCATENATED MODULE: ./src/i18n/index.js

var DEFAULT_LANG = 'en';
var i18n = {
  translations: {}
};
var getLanguage = function getLanguage(deviceLang) {
  if (deviceLang) {
    return deviceLang;
  }

  return (navigator.language || navigator.languages && navigator.languages.length && navigator.languages[0]).toLowerCase();
};

var getSuffix = function getSuffix(language) {
  var lang = language.toLowerCase();
  return lang_mapping_namespaceObject[lang] || lang_mapping_namespaceObject[lang.substr(0, 2)] || DEFAULT_LANG;
};

var initI18n = function initI18n(language) {
  var suffix = getSuffix(language);
  i18n.translations = __webpack_require__(878)("./translations_".concat(suffix, ".json"));
};
var t = function t(key) {
  return i18n.translations[key];
};
var loadTranslations = function loadTranslations() {
  var elements = document.querySelectorAll('[data-lang-key]');
  elements.forEach(function (element) {
    var key = element.dataset.langKey;
    var translation = t(key);
    element.innerHTML = translation;
  });
  var placeholders = document.querySelectorAll('[data-lang-placeholder-key]');
  placeholders.forEach(function (element) {
    var key = element.dataset.langPlaceholderKey;
    var translation = t(key);
    element.placeholder = translation;
  });
};
;// CONCATENATED MODULE: ./src/services/validator.js

var FOUR_DIGIT_YEAR = 1000;
var YEARS_MARGIN = 125;
var VALIDATIONS = {
  EMPTY: {
    valid: false,
    text: 'aadc-notification-emptyfield'
  },
  DATE_IN_FUTURE: {
    valid: false,
    text: 'aadc-notification-timetravel'
  },
  YEAR_TOO_SHORT: {
    valid: false,
    text: 'aadc-notification-badyear'
  },
  INVALID_DAY: {
    valid: false,
    text: 'aadc-notification-validdate'
  },
  GENERIC_ERROR: {
    valid: false
  },
  DATE_OK: {
    valid: true
  }
};

var validateRequired = function validateRequired(input) {
  if (input.value) {
    input.classList.remove('has-error');
    return VALIDATIONS.DATE_OK;
  }

  input.classList.add('has-error');
  return VALIDATIONS.EMPTY;
};

var validateYear = function validateYear(input) {
  var isEmpty = validateRequired(input);

  if (!isEmpty.valid) {
    return isEmpty;
  }

  var value = parseInt(input.value);
  var currentYear = dayjs_min_default()().year();

  if (value > currentYear) {
    input.classList.add('has-error');
    return VALIDATIONS.DATE_IN_FUTURE;
  }

  if (value < FOUR_DIGIT_YEAR) {
    input.classList.add('has-error');
    return VALIDATIONS.YEAR_TOO_SHORT;
  }

  if (value < currentYear - YEARS_MARGIN) {
    input.classList.add('has-error');
    return VALIDATIONS.GENERIC_ERROR;
  }

  input.classList.remove('has-error');
  return VALIDATIONS.DATE_OK;
};

var validateMonth = function validateMonth(input) {
  var isEmpty = validateRequired(input);

  if (!isEmpty.valid) {
    return isEmpty;
  }

  var value = input.value;

  if (value > 12) {
    input.classList.add('has-error');
    return VALIDATIONS.GENERIC_ERROR;
  }

  if (value < 1) {
    input.classList.add('has-error');
    return VALIDATIONS.GENERIC_ERROR;
  }

  input.classList.remove('has-error');
  return VALIDATIONS.DATE_OK;
};

var validateDay = function validateDay(input) {
  var isEmpty = validateRequired(input);

  if (!isEmpty.valid) {
    return isEmpty;
  }

  var value = input.value;

  if (value > 31) {
    input.classList.add('has-error');
    return VALIDATIONS.GENERIC_ERROR;
  }

  if (value < 1) {
    input.classList.add('has-error');
    return VALIDATIONS.GENERIC_ERROR;
  }

  input.classList.remove('has-error');
  return VALIDATIONS.DATE_OK;
};

var validateField = function validateField(e) {
  var input = e.target;

  switch (input.id) {
    case 'year':
      return validateYear(input);

    case 'month':
      return validateMonth(input);

    case 'day':
      return validateDay(input);

    default:
      break;
  }
};
var validateCombination = function validateCombination(_ref) {
  var yearInput = _ref.yearInput,
      monthInput = _ref.monthInput,
      dayInput = _ref.dayInput;

  if (!yearInput.value || !monthInput.value) {
    return VALIDATIONS.DATE_OK;
  }

  var currentDate = dayjs_min_default()();
  var inputDate = dayjs_min_default()().year(parseInt(yearInput.value)).month(parseInt(monthInput.value) - 1).date(!!dayInput.value && parseInt(dayInput.value) || currentDate.date());

  if (inputDate.isAfter(currentDate)) {
    monthInput.classList.add('has-error');

    if (!!dayInput.value) {
      yearInput.classList.add('has-error');
      dayInput.classList.add('has-error');
      return VALIDATIONS.DATE_IN_FUTURE;
    }

    return VALIDATIONS.GENERIC_ERROR;
  }

  if (inputDate.isBefore(currentDate.subtract(YEARS_MARGIN, 'years'))) {
    return VALIDATIONS.GENERIC_ERROR;
  }

  if (!!dayInput.value && inputDate.date() !== parseInt(dayInput.value)) {
    // Dayjs jumps to next day if date is not valid (ie: March 32nd is set as April 1st)
    monthInput.classList.add('has-error');
    dayInput.classList.add('has-error');
    return VALIDATIONS.INVALID_DAY;
  }

  var singulars = [];
  if (!!yearInput.value) singulars.push(validateYear(yearInput));
  if (!!monthInput.value) singulars.push(validateMonth(monthInput));
  if (!!dayInput.value) singulars.push(validateDay(dayInput));
  return singulars.find(function (validation) {
    return !validation.valid;
  }) || VALIDATIONS.DATE_OK;
};
var validateForm = function validateForm(dayInput, monthInput, yearInput) {
  var result = [validateYear(yearInput), validateMonth(monthInput), validateDay(dayInput), validateCombination({
    yearInput: yearInput,
    monthInput: monthInput,
    dayInput: dayInput
  })];
  return result;
};
;// CONCATENATED MODULE: ./src/utils/messages.js
var MESSAGES = Object.freeze({
  READY: 'READY',
  LOADED_VIEW: 'LOADED_VIEW',
  SUBMIT_AGE_GATE: 'SUBMIT_AGE_GATE',
  OPEN_LINK: 'OPEN_LINK',
  INTERACTION: 'INTERACTION',
  FORM_SUBMIT: 'FORM_SUBMIT',
  CONTACT: 'CONTACT',
  CLOSE: 'CLOSE',
  ON_SET_SCENARIO: 'ON_SET_SCENARIO',
  ON_ERROR: 'ON_ERROR'
});
;// CONCATENATED MODULE: ./src/utils/interactions.js
var SCENARIOS = Object.freeze({
  SCENARIO_0: 'REQUEST',
  SCENARIO_1: 'BLOCK',
  SCENARIO_2: 'RESTRICTED',
  SCENARIO_3: 'RESTRICTED'
});
var INTERACTIONS = Object.freeze({
  REQUEST_GUI_ID: 1700,
  BLOCK_GUI_ID: 1701,
  RESTRICTED_GUI_ID: 1703,
  SUBMIT_ACTION_ID: 100,
  OK_ACTION_ID: 101,
  CONTACT_ACTION_ID: 102,
  TOU_ACTION_ID: 22,
  PP_ACTION_ID: 40,
  CLOSE_ACTION_ID: 0,
  BACK_ACTION_ID: 1
});
var FORM_SUBMIT = Object.freeze({
  SUCCESS: {
    submitted: true,
    guiId: 1700
  }
});
var BACK_BUTTON_ACTIONS = Object.freeze({
  DISABLE: 'DISABLE',
  ENABLE: 'ENABLE'
});
;// CONCATENATED MODULE: ./src/utils/errors.js
var ERRORS = Object.freeze({
  ERROR_5: 'notification-nointernetconnection',
  ERROR_16: 'notification-somethingwentwrong'
});
;// CONCATENATED MODULE: ./src/services/manager.js
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }






var REQUEST_SCENARIO = 0;
var BLOCK_SCENARIO = 1; // Logger

var logHeader = '[Webview/Age-Gate] ';
var log = function log(text) {
  console.log("".concat(logHeader, " ").concat(text));
}; // Comms

var listenForScenario = function listenForScenario(hook) {
  comChannel.setMessageHook(MESSAGES.ON_SET_SCENARIO, function (message, rawPayload) {
    var payload = JSON.parse(rawPayload);
    var scenario = parseInt(payload.scenario);
    log("[".concat(message, "] received with payload ").concat(JSON.stringify(payload)));
    hook(scenario);

    if ([REQUEST_SCENARIO, BLOCK_SCENARIO].includes(scenario)) {
      handleBackButton(BACK_BUTTON_ACTIONS.DISABLE, scenario);
    } else {
      handleBackButton(BACK_BUTTON_ACTIONS.ENABLE, scenario);
    }
  }); // TODO: Implement a more robust solution

  var startupDelaySeconds = 0.25;
  setTimeout(function () {
    return comChannel.postMessage(MESSAGES.READY, {
      version: "0.4.4"
    });
  }, startupDelaySeconds * 1000);
};
var handleBackButton = function handleBackButton(action, scenario, submitData) {
  var fn = null;

  if (action === BACK_BUTTON_ACTIONS.DISABLE) {
    log("[handleBackButton] disable button");

    fn = function fn() {
      trackBackButton(scenario);
      log("Back button is disabled");
    };
  } else {
    log("[handleBackButton] enable button");

    fn = function fn() {
      trackBackButton(scenario);
      closeView(_objectSpread(_objectSpread({}, submitData), {}, {
        submitted: false
      }));
    };
  }

  comChannel.setMessageHook(comChannel.Messages.SYSTEM_BACK_BUTTON, fn);
};
var sendDate = function sendDate(date, trackData, errorHook) {
  var submitData = _objectSpread({
    guiId: INTERACTIONS.REQUEST_GUI_ID
  }, trackData);

  comChannel.setMessageHook(MESSAGES.ON_ERROR, function (message, rawPayload) {
    var payload = JSON.parse(rawPayload);
    log("[".concat(message, "] received with payload ").concat(JSON.stringify(payload)));
    var errorKey = ERRORS["ERROR_".concat(payload.errorCode)];
    var errorText = t(errorKey);
    errorHook(errorText);
    handleBackButton(BACK_BUTTON_ACTIONS.ENABLE, REQUEST_SCENARIO, submitData);
  });
  comChannel.postMessage(MESSAGES.SUBMIT_AGE_GATE, {
    dateOfBirth: date.format('YYYY-MM-DD'),
    submitData: submitData
  });
}; // Actions

var openLink = function openLink(e) {
  e.preventDefault();
  trackInteraction(e);
  var url = e.target.getAttribute('href');
  comChannel.postMessage(MESSAGES.OPEN_LINK, {
    url: url
  });
};
var contact = function contact() {
  comChannel.postMessage(MESSAGES.CONTACT);
};
var closeView = function closeView(trackData) {
  if (!trackData) {
    comChannel.postMessage(MESSAGES.CLOSE, {});
    return;
  }

  var submitData = _objectSpread(_objectSpread({}, trackData), {}, {
    guiId: INTERACTIONS.REQUEST_GUI_ID
  });

  comChannel.postMessage(MESSAGES.CLOSE, {
    submitData: submitData
  });
}; // Tracking

var trackLoadedView = function trackLoadedView(scenario, guiCount) {
  log("Page was loaded with scenario '".concat(scenario, "'"));
  var gui = SCENARIOS["SCENARIO_".concat(scenario)];
  var guiId = INTERACTIONS["".concat(gui, "_GUI_ID")];
  comChannel.postMessage(MESSAGES.LOADED_VIEW, {
    guiId: guiId,
    guiCount: guiCount
  });
};
var trackInteraction = function trackInteraction(e) {
  var action = e.currentTarget.dataset.action;
  var gui = e.currentTarget.dataset.gui;
  log("'".concat(action, "' in '").concat(gui, "' was clicked"));
  var guiId = INTERACTIONS["".concat(gui, "_GUI_ID")];
  var actionId = INTERACTIONS["".concat(action, "_ACTION_ID")];
  comChannel.postMessage(MESSAGES.INTERACTION, {
    guiId: guiId,
    actionId: actionId
  });
};

var trackBackButton = function trackBackButton(scenario) {
  var gui = SCENARIOS["SCENARIO_".concat(scenario)];
  log("'BACK' in '".concat(gui, "' was clicked"));
  var guiId = INTERACTIONS["".concat(gui, "_GUI_ID")];
  var actionId = INTERACTIONS.BACK_ACTION_ID;
  comChannel.postMessage(MESSAGES.INTERACTION, {
    guiId: guiId,
    actionId: actionId
  });
}; // Animation


var animate = function animate(e) {
  if (e.target.disabled) {
    return;
  }

  e.target.classList.add('is-animated');
  setTimeout(function () {
    e.target.classList.remove('is-animated');
  }, 800);
};

var animateElements = function animateElements(elements) {
  var _ref;

  (_ref = []).concat.apply(_ref, _toConsumableArray(elements)).forEach(function (element) {
    element.addEventListener('mousedown', animate);
    element.addEventListener('touchstart', animate);
  });
}; // Notifications

var NOTIFICATION_DISMISS_TIME = 6000;
var timeout;
var showNotification = function showNotification(notification, text) {
  if (timeout) {
    clearTimeout(timeout);
  }

  notification.innerText = text;
  notification.classList.remove('mb-notification--dismiss');
  notification.classList.remove('is-hidden');
  timeout = setTimeout(function () {
    notification.classList.add('mb-notification--dismiss');
  }, NOTIFICATION_DISMISS_TIME);
};
;// CONCATENATED MODULE: ./src/index.js














function initEvents() {
  var container = document.querySelector('#king-container');
  var form = document.querySelector('#age-gate');
  var yearInput = document.querySelector('#year');
  var monthInput = document.querySelector('#month');
  var dayInput = document.querySelector('#day');
  var saveButton = document.querySelector('#button-save');
  var contactBlockButton = document.querySelector('#button-block-contact');
  var contactRestrictedButton = document.querySelector('#button-restricted-contact');
  var okButton = document.querySelector('#button-ok');
  var errorNotification = document.querySelector('#error');
  var closeRequestButton = document.querySelector('#close-request-button');
  var closeBlockButton = document.querySelector('#close-block-button');
  var extLink = document.querySelectorAll('.ext-link');
  var numClientErrors = 0;
  var lastFieldInteracted = 0;
  var updateTypeId = 0;
  var guiCount = 0;

  var handleSetScenario = function handleSetScenario(scenario) {
    container.dataset.scenario = scenario;
    guiCount++;
    trackLoadedView(scenario, guiCount);
  };

  var onClickSave = function onClickSave(e) {
    e.preventDefault();
    var formValidations = validateForm(dayInput, monthInput, yearInput);
    var errors = formValidations.filter(function (validation) {
      return !validation.valid;
    }).length;
    numClientErrors = numClientErrors + errors;

    if (errors > 0) {
      return;
    }

    var date = dayjs_min_default()().year(parseInt(yearInput.value)).month(parseInt(monthInput.value) - 1).date(parseInt(dayInput.value));
    trackInteraction(e);
    var submitData = {
      submitted: true,
      numClientErrors: numClientErrors,
      lastFieldInteracted: lastFieldInteracted,
      updateTypeId: updateTypeId
    };

    var errorHook = function errorHook(errorText) {
      yearInput.disabled = false;
      monthInput.disabled = false;
      dayInput.disabled = false;
      saveButton.classList.remove('is-loading');
      closeRequestButton.classList.remove('is-hidden');
      showNotification(errorNotification, errorText);
    };

    yearInput.disabled = true;
    monthInput.disabled = true;
    dayInput.disabled = true;
    saveButton.classList.add('is-loading');
    sendDate(date, submitData, errorHook);
  };

  var onClickContact = function onClickContact(e) {
    e.preventDefault();
    trackInteraction(e);
    contact();
  };

  var onClickCloseRequest = function onClickCloseRequest(e) {
    e.preventDefault();
    trackInteraction(e);
    closeView({
      submitted: false,
      numClientErrors: numClientErrors,
      lastFieldInteracted: lastFieldInteracted,
      updateTypeId: updateTypeId
    });
  };

  var onClickCloseBlock = function onClickCloseBlock(e) {
    e.preventDefault();
    trackInteraction(e);
    closeView();
  };

  var validateSingleField = function validateSingleField(e) {
    lastFieldInteracted = parseInt(e.target.dataset.orderId);
    updateTypeId = 1;
    var validation = validateField(e);

    if (validation.valid) {
      return;
    }

    numClientErrors++;

    if (!validation.text) {
      return;
    }

    showNotification(errorNotification, t(validation.text));
  };

  var validateAllFields = function validateAllFields() {
    var validation = validateCombination({
      yearInput: yearInput,
      monthInput: monthInput,
      dayInput: dayInput
    });
    saveButton.disabled = !validation.valid || !yearInput.value || !monthInput.value || !dayInput.value;

    if (validation.valid) {
      return;
    }

    numClientErrors++;

    if (!validation.text) {
      return;
    }

    showNotification(errorNotification, t(validation.text));
  };

  var onInput = debounce(function (e) {
    validateSingleField(e);
    validateAllFields(e);
  });
  [yearInput, monthInput, dayInput].forEach(function (input) {
    input.addEventListener('keydown', onInput);
  });
  monthInput.addEventListener('change', onInput);
  yearInput.setAttribute('min', dayjs_min_default()().year() - YEARS_MARGIN);
  yearInput.setAttribute('max', dayjs_min_default()().year());
  saveButton.addEventListener('click', onClickSave);
  saveButton.addEventListener('tap', onClickSave);
  form.addEventListener('submit', onClickSave);
  contactBlockButton.addEventListener('click', onClickContact);
  contactRestrictedButton.addEventListener('click', onClickContact);
  contactBlockButton.addEventListener('tap', onClickContact);
  contactRestrictedButton.addEventListener('tap', onClickContact);
  closeRequestButton.addEventListener('click', onClickCloseRequest);
  closeRequestButton.addEventListener('tap', onClickCloseRequest);
  [okButton, closeBlockButton].forEach(function (btn) {
    btn.addEventListener('click', onClickCloseBlock);
    btn.addEventListener('tap', onClickCloseBlock);
  });
  extLink.forEach(function (link) {
    link.addEventListener('click', openLink);
    link.addEventListener('tap', openLink);
  });
  animateElements([saveButton, contactBlockButton, contactRestrictedButton, okButton, closeRequestButton, closeBlockButton, toArray(extLink)]);
  listenForScenario(handleSetScenario);
}

document.addEventListener('NativeAppReady', function (e) {
  log("Event 'NativeAppReady' received");
  initEvents();
  var language = getLanguage(e.detail.language);
  initI18n(language);
  document.documentElement.lang = language;
  loadTranslations();
});
document.addEventListener('touchstart', function () {}, true);

/***/ }),

/***/ 753:
/***/ (() => {

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * In old versions of Safari Mobile (iOS <= 12), elements with fixed positions behave weirdly when focusing on an input.
 * In order to fix them, these inputs need to be changed to an absolute position everytime an input is focused, and returned to a fixed position when the input loses focus.
 *
 * Source: https://dansajin.com/2012/12/07/fix-position-fixed/
 */
var apply = function apply() {
  var body = document.querySelector('body');
  body.classList.add('fix-fixed');
};

var restore = function restore() {
  var body = document.querySelector('body');
  body.classList.remove('fix-fixed');
  body.scrollIntoView();
};

var inputs = document.querySelectorAll('input');
var selects = document.querySelectorAll('select');
[].concat(_toConsumableArray(inputs), _toConsumableArray(selects)).forEach(function (input) {
  input.addEventListener('focus', function () {
    apply();
  });
  input.addEventListener('blur', function () {
    restore();
  });
});

/***/ }),

/***/ 653:
/***/ (() => {

/**
 * This fix is applied as a workaround for an issue encountered with Select inputs used in webviews in Android devices.
 *
 * It detects Android devices and displays a compatible Text input instead of a Select
 */
var apply = function apply() {
  var monthSelect = document.querySelector('#month');
  var monthText = document.querySelector('#month-text');
  var form = document.querySelector('#age-gate');
  var isAndroid = navigator.userAgent.match(/Android/i);

  if (!isAndroid) {
    monthText.remove();
    return;
  }

  monthSelect.remove();
  monthText.id = 'month';
  form.classList.add('center');
};

document.addEventListener('DOMContentLoaded', function (_) {
  apply();
});

/***/ }),

/***/ 540:
/***/ (() => {

var originalWidth, originalHeight;
var change = true;

var orientation = function orientation() {
  var temp = originalWidth;
  originalWidth = originalHeight;
  originalHeight = temp;
  change = true;
  apply();
};

var apply = function apply() {
  window.removeEventListener('orientationchange', orientation);
  var viewWidth = window.innerWidth;
  var viewHeight = window.innerHeight;

  if (!originalWidth && !originalHeight) {
    originalWidth = viewWidth;
    originalHeight = viewHeight;
  }

  var viewport = window.document.querySelector('meta[name=viewport]');
  var content = viewport.getAttribute('content');
  change = false;
  viewport.setAttribute('content', content.replace(/width=(device-width|\d*px)/, "width=".concat(originalWidth, "px")).replace(/height=(device-height|\d*px)/, "height=".concat(originalHeight, "px")));
  window.addEventListener('orientationchange', orientation);
};

var restore = function restore() {
  change = true;
  window.removeEventListener('orientationchange', orientation);
  setTimeout(function () {
    if (change) {
      var viewport = window.document.querySelector('meta[name=viewport]');
      var content = viewport.getAttribute('content');
      viewport.setAttribute('content', content.replace(/width=\d+px/, 'width=device-width').replace(/height=\d+px/, 'height=device-height'));
      originalWidth = null;
      originalHeight = null;
    }
  }, 200);
};

document.addEventListener('focusin', function () {
  apply();
});
document.addEventListener('focusout', function () {
  restore();
});

/***/ }),

/***/ 484:
/***/ (function(module) {

!function(t,e){ true?module.exports=e():0}(this,(function(){"use strict";var t=1e3,e=6e4,n=36e5,r="millisecond",i="second",s="minute",u="hour",a="day",o="week",f="month",h="quarter",c="year",d="date",$="Invalid Date",l=/^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[^0-9]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/,y=/\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g,M={name:"en",weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_")},m=function(t,e,n){var r=String(t);return!r||r.length>=e?t:""+Array(e+1-r.length).join(n)+t},g={s:m,z:function(t){var e=-t.utcOffset(),n=Math.abs(e),r=Math.floor(n/60),i=n%60;return(e<=0?"+":"-")+m(r,2,"0")+":"+m(i,2,"0")},m:function t(e,n){if(e.date()<n.date())return-t(n,e);var r=12*(n.year()-e.year())+(n.month()-e.month()),i=e.clone().add(r,f),s=n-i<0,u=e.clone().add(r+(s?-1:1),f);return+(-(r+(n-i)/(s?i-u:u-i))||0)},a:function(t){return t<0?Math.ceil(t)||0:Math.floor(t)},p:function(t){return{M:f,y:c,w:o,d:a,D:d,h:u,m:s,s:i,ms:r,Q:h}[t]||String(t||"").toLowerCase().replace(/s$/,"")},u:function(t){return void 0===t}},D="en",v={};v[D]=M;var p=function(t){return t instanceof _},S=function(t,e,n){var r;if(!t)return D;if("string"==typeof t)v[t]&&(r=t),e&&(v[t]=e,r=t);else{var i=t.name;v[i]=t,r=i}return!n&&r&&(D=r),r||!n&&D},w=function(t,e){if(p(t))return t.clone();var n="object"==typeof e?e:{};return n.date=t,n.args=arguments,new _(n)},O=g;O.l=S,O.i=p,O.w=function(t,e){return w(t,{locale:e.$L,utc:e.$u,x:e.$x,$offset:e.$offset})};var _=function(){function M(t){this.$L=S(t.locale,null,!0),this.parse(t)}var m=M.prototype;return m.parse=function(t){this.$d=function(t){var e=t.date,n=t.utc;if(null===e)return new Date(NaN);if(O.u(e))return new Date;if(e instanceof Date)return new Date(e);if("string"==typeof e&&!/Z$/i.test(e)){var r=e.match(l);if(r){var i=r[2]-1||0,s=(r[7]||"0").substring(0,3);return n?new Date(Date.UTC(r[1],i,r[3]||1,r[4]||0,r[5]||0,r[6]||0,s)):new Date(r[1],i,r[3]||1,r[4]||0,r[5]||0,r[6]||0,s)}}return new Date(e)}(t),this.$x=t.x||{},this.init()},m.init=function(){var t=this.$d;this.$y=t.getFullYear(),this.$M=t.getMonth(),this.$D=t.getDate(),this.$W=t.getDay(),this.$H=t.getHours(),this.$m=t.getMinutes(),this.$s=t.getSeconds(),this.$ms=t.getMilliseconds()},m.$utils=function(){return O},m.isValid=function(){return!(this.$d.toString()===$)},m.isSame=function(t,e){var n=w(t);return this.startOf(e)<=n&&n<=this.endOf(e)},m.isAfter=function(t,e){return w(t)<this.startOf(e)},m.isBefore=function(t,e){return this.endOf(e)<w(t)},m.$g=function(t,e,n){return O.u(t)?this[e]:this.set(n,t)},m.unix=function(){return Math.floor(this.valueOf()/1e3)},m.valueOf=function(){return this.$d.getTime()},m.startOf=function(t,e){var n=this,r=!!O.u(e)||e,h=O.p(t),$=function(t,e){var i=O.w(n.$u?Date.UTC(n.$y,e,t):new Date(n.$y,e,t),n);return r?i:i.endOf(a)},l=function(t,e){return O.w(n.toDate()[t].apply(n.toDate("s"),(r?[0,0,0,0]:[23,59,59,999]).slice(e)),n)},y=this.$W,M=this.$M,m=this.$D,g="set"+(this.$u?"UTC":"");switch(h){case c:return r?$(1,0):$(31,11);case f:return r?$(1,M):$(0,M+1);case o:var D=this.$locale().weekStart||0,v=(y<D?y+7:y)-D;return $(r?m-v:m+(6-v),M);case a:case d:return l(g+"Hours",0);case u:return l(g+"Minutes",1);case s:return l(g+"Seconds",2);case i:return l(g+"Milliseconds",3);default:return this.clone()}},m.endOf=function(t){return this.startOf(t,!1)},m.$set=function(t,e){var n,o=O.p(t),h="set"+(this.$u?"UTC":""),$=(n={},n[a]=h+"Date",n[d]=h+"Date",n[f]=h+"Month",n[c]=h+"FullYear",n[u]=h+"Hours",n[s]=h+"Minutes",n[i]=h+"Seconds",n[r]=h+"Milliseconds",n)[o],l=o===a?this.$D+(e-this.$W):e;if(o===f||o===c){var y=this.clone().set(d,1);y.$d[$](l),y.init(),this.$d=y.set(d,Math.min(this.$D,y.daysInMonth())).$d}else $&&this.$d[$](l);return this.init(),this},m.set=function(t,e){return this.clone().$set(t,e)},m.get=function(t){return this[O.p(t)]()},m.add=function(r,h){var d,$=this;r=Number(r);var l=O.p(h),y=function(t){var e=w($);return O.w(e.date(e.date()+Math.round(t*r)),$)};if(l===f)return this.set(f,this.$M+r);if(l===c)return this.set(c,this.$y+r);if(l===a)return y(1);if(l===o)return y(7);var M=(d={},d[s]=e,d[u]=n,d[i]=t,d)[l]||1,m=this.$d.getTime()+r*M;return O.w(m,this)},m.subtract=function(t,e){return this.add(-1*t,e)},m.format=function(t){var e=this;if(!this.isValid())return $;var n=t||"YYYY-MM-DDTHH:mm:ssZ",r=O.z(this),i=this.$locale(),s=this.$H,u=this.$m,a=this.$M,o=i.weekdays,f=i.months,h=function(t,r,i,s){return t&&(t[r]||t(e,n))||i[r].substr(0,s)},c=function(t){return O.s(s%12||12,t,"0")},d=i.meridiem||function(t,e,n){var r=t<12?"AM":"PM";return n?r.toLowerCase():r},l={YY:String(this.$y).slice(-2),YYYY:this.$y,M:a+1,MM:O.s(a+1,2,"0"),MMM:h(i.monthsShort,a,f,3),MMMM:h(f,a),D:this.$D,DD:O.s(this.$D,2,"0"),d:String(this.$W),dd:h(i.weekdaysMin,this.$W,o,2),ddd:h(i.weekdaysShort,this.$W,o,3),dddd:o[this.$W],H:String(s),HH:O.s(s,2,"0"),h:c(1),hh:c(2),a:d(s,u,!0),A:d(s,u,!1),m:String(u),mm:O.s(u,2,"0"),s:String(this.$s),ss:O.s(this.$s,2,"0"),SSS:O.s(this.$ms,3,"0"),Z:r};return n.replace(y,(function(t,e){return e||l[t]||r.replace(":","")}))},m.utcOffset=function(){return 15*-Math.round(this.$d.getTimezoneOffset()/15)},m.diff=function(r,d,$){var l,y=O.p(d),M=w(r),m=(M.utcOffset()-this.utcOffset())*e,g=this-M,D=O.m(this,M);return D=(l={},l[c]=D/12,l[f]=D,l[h]=D/3,l[o]=(g-m)/6048e5,l[a]=(g-m)/864e5,l[u]=g/n,l[s]=g/e,l[i]=g/t,l)[y]||g,$?D:O.a(D)},m.daysInMonth=function(){return this.endOf(f).$D},m.$locale=function(){return v[this.$L]},m.locale=function(t,e){if(!t)return this.$L;var n=this.clone(),r=S(t,e,!0);return r&&(n.$L=r),n},m.clone=function(){return O.w(this.$d,this)},m.toDate=function(){return new Date(this.valueOf())},m.toJSON=function(){return this.isValid()?this.toISOString():null},m.toISOString=function(){return this.$d.toISOString()},m.toString=function(){return this.$d.toUTCString()},M}(),b=_.prototype;return w.prototype=b,[["$ms",r],["$s",i],["$m",s],["$H",u],["$W",a],["$M",f],["$y",c],["$D",d]].forEach((function(t){b[t[1]]=function(e){return this.$g(e,t[0],t[1])}})),w.extend=function(t,e){return t.$i||(t(e,_,w),t.$i=!0),w},w.locale=S,w.isDayjs=p,w.unix=function(t){return w(1e3*t)},w.en=v[D],w.Ls=v,w.p={},w}));

/***/ }),

/***/ 654:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Ups, der gik noget galt. Prøv igen senere.","notification-nointernetconnection":"Du er offline. Forbind til internettet først.","link-pp":"Fortrolighedspolitik","aadc-title-textlabel":"Hvornår er det din fødselsdag?","aadc-subtitle-textlabel":"Vi spørger til din fødselsdag for at sikre, at du får den bedst mulige oplevelse.","aadc-year-inline":"År","aadc-month-inline":"Måned","aadc-day":"Dag","aadc-year-hint":"ÅÅÅÅ","aadc-day-hint":"DD","aadc-continue-button":"FORTSÆT","aadc-legal-disclaimer-textlabel":"Din fødselsdag bliver ikke offentliggjort eller delt med en tredjepart.","aadc-month-jan":"Januar","aadc-month-feb":"Februar","aadc-month-mar":"Marts","aadc-month-apr":"April","aadc-month-may":"Maj","aadc-month-jun":"Juni","aadc-month-jul":"Juli","aadc-month-aug":"August","aadc-month-sep":"September","aadc-month-oct":"Oktober","aadc-month-nov":"November","aadc-month-dec":"December","aadc-block-title":"Ups! Det ser ud til, at du ikke kan spille nu","aadc-block-subtitle-textdialog":"Beklager, det ser ud til, at du ikke har adgang til dette spil.","link-tou":"Brugsbetingelser","aadc-notification-badyear":"Indtast dit fødselsår med 4 cifre.","aadc-notification-emptyfield":"Vi skal bruge år, måned og dag.","aadc-notification-validdate":"Fødselsdatoen lader ikke til at være gyldig.","aadc-button-contactus":"Kontakt os","aadc-title-restricted":"Du spiller nu en ufuldstændig version af spillet","aadc-textlabel-contactus":"Hvis du har nogen spørgsmål, så","aadc-button-gotit":"Modtaget!","aadc-notification-timetravel":"Fødselsdagen skal være den dato, du blev født.","aadc-abb-jan":"Jan.","aadc-abb-feb":"Feb.","aadc-abb-mar":"Mar.","aadc-abb-apr":"Apr.","aadc-abb-may":"Maj","aadc-abb-jun":"Juni","aadc-abb-july":"Juli","aadc-abb-aug":"Aug.","aadc-abb-sep":"Sept.","aadc-abb-oct":"Okt.","aadc-abb-nov":"Nov.","aadc-abb-dec":"Dec.","aadc-textlabel-agegate-desc":"Dette er nødvendigt, så vi kan skræddersy spiloplevelsen under lokale regulativer.","aadc-textlabel-agegate":"Beklager, men du kan ikke tilgå spillet lige nu grundet lokale regulativer.","aadc-block-subtitle2-texdialog":"På grund af lokale regulativer er nogle af spilfunktionerne slået fra.","aadc-block-subtitle3-texdialog":"Du kan stadig slå de funktioner til i spillet.","aadc-texlabel-name-disclaimer":"(Bliver offentligt)","aadc-textlabel-signup-disclaimer":"Ved at oprette en konto accepterer du {link-tou} og har læst {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Dit navn vil blive vist offentligt. Brug et kaldenavn.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 154:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Ein Fehler ist aufgetreten. Versuche es später erneut.","notification-nointernetconnection":"Offline. Verbinde dich und versuche es erneut.","link-pp":"Datenschutzrichtlinie","aadc-title-textlabel":"Wann hast du Geburtstag?","aadc-subtitle-textlabel":"Wir fragen dich nach deinem Geburtstag, um dir eine optimale Erfahrung zu bieten.","aadc-year-inline":"Jahr","aadc-month-inline":"Monat","aadc-day":"Tag","aadc-year-hint":"JJJJ","aadc-day-hint":"TT","aadc-continue-button":"WEITER","aadc-legal-disclaimer-textlabel":"Dein Geburtsdatum wird nicht öffentlich angezeigt oder an Dritte weitergegeben.","aadc-month-jan":"Januar","aadc-month-feb":"Februar","aadc-month-mar":"März","aadc-month-apr":"April","aadc-month-may":"Mai","aadc-month-jun":"Juni","aadc-month-jul":"Juli","aadc-month-aug":"August","aadc-month-sep":"September","aadc-month-oct":"Oktober","aadc-month-nov":"November","aadc-month-dec":"Dezember","aadc-block-title":"Hoppla! Anscheinend kannst du derzeit nicht spielen.","aadc-block-subtitle-textdialog":"Es tut uns leid, aber du bist für dieses Spiel nicht zugriffsberechtigt.","link-tou":"Nutzungsbedingungen","aadc-notification-badyear":"Gib dein Geburtsjahr als vierstellige Zahl ein.","aadc-notification-emptyfield":"Jahr, Monat und Tag sind Pflichtangaben.","aadc-notification-validdate":"Dein Geburtsdatum scheint ungültig zu sein.","aadc-button-contactus":"Kontakt","aadc-title-restricted":"Du spielst jetzt eine Lite-Version des Spiels.","aadc-textlabel-contactus":"Wende dich bei Fragen an uns.","aadc-button-gotit":"Verstanden!","aadc-notification-timetravel":"Dein Geburtstag muss deinem Geburtsdatum entsprechen.","aadc-abb-jan":"Jan.","aadc-abb-feb":"Feb.","aadc-abb-mar":"März","aadc-abb-apr":"Apr.","aadc-abb-may":"Mai","aadc-abb-jun":"Juni","aadc-abb-july":"Juli","aadc-abb-aug":"Aug.","aadc-abb-sep":"Sept.","aadc-abb-oct":"Okt.","aadc-abb-nov":"Nov.","aadc-abb-dec":"Dez.","aadc-textlabel-agegate-desc":"Diese Angabe ist erforderlich, damit wir deine Spielerfahrung im Einklang mit den regionalen Vorschriften personalisieren können.","aadc-textlabel-agegate":"Es tut uns leid. Aufgrund von regionalen Vorschriften hast du derzeit leider keinen Zugang zu diesem Spiel.","aadc-block-subtitle2-texdialog":"Aufgrund von regionalen Vorschriften wurden einige Funktionen deaktiviert.","aadc-block-subtitle3-texdialog":"Du kannst diese Funktionen jedoch im Spiel aktivieren.","aadc-texlabel-name-disclaimer":"(wird öffentlich angezeigt)","aadc-textlabel-signup-disclaimer":"Durch die Erstellung eines Kontos stimmst du den {link-tou} zu und bestätigst, dass du die {link-pp} gelesen hast.","aadc-texlabel-name-disclaimer-edit":"Dein Name wird öffentlich angezeigt. Verwende einen Spitznamen.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 517:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Oops, something went wrong. Please, try again later.","notification-nointernetconnection":"You\'re offline. Connect to Internet and try again.","link-pp":"Privacy Policy","aadc-title-textlabel":"When is your birthday?","aadc-subtitle-textlabel":"We ask for your birthday to ensure we give you the best possible experience.","aadc-year-inline":"Year","aadc-month-inline":"Month","aadc-day":"Day","aadc-year-hint":"YYYY","aadc-day-hint":"DD","aadc-continue-button":"CONTINUE","aadc-legal-disclaimer-textlabel":"Your date of birth won\'t be public, nor shared with any third party.","aadc-month-jan":"January","aadc-month-feb":"February","aadc-month-mar":"March","aadc-month-apr":"April","aadc-month-may":"May","aadc-month-jun":"June","aadc-month-jul":"July","aadc-month-aug":"August","aadc-month-sep":"September","aadc-month-oct":"October","aadc-month-nov":"November","aadc-month-dec":"December","aadc-block-title":"Oops! It looks like you cannot play now","aadc-block-subtitle-textdialog":"Sorry, it looks like you are not eligible for this game.","link-tou":"Terms of Use","aadc-notification-badyear":"Please enter birth year as 4 digits.","aadc-notification-emptyfield":"Year, month and day are all required.","aadc-notification-validdate":"The birthday doesn\'t seem to be a valid date.","aadc-button-contactus":"Contact us","aadc-title-restricted":"You are now playing a lite version of the game","aadc-textlabel-contactus":"If you have any questions, please","aadc-button-gotit":"Got it!","aadc-notification-timetravel":"The birthday must be the date you were born.","aadc-abb-jan":"Jan.","aadc-abb-feb":"Feb.","aadc-abb-mar":"Mar.","aadc-abb-apr":"Apr.","aadc-abb-may":"May","aadc-abb-jun":"June","aadc-abb-july":"July","aadc-abb-aug":"Aug.","aadc-abb-sep":"Sept.","aadc-abb-oct":"Oct.","aadc-abb-nov":"Nov.","aadc-abb-dec":"Dec.","aadc-textlabel-agegate-desc":"This is required so we can tailor the gameplay experience within regional regulations.","aadc-textlabel-agegate":"Sorry, you cannot access the game at this time due to regional regulations.","aadc-block-subtitle2-texdialog":"Due to regional regulations, some of the features have been turned off.","aadc-block-subtitle3-texdialog":"You will still be able to turn those features on in the game.","aadc-texlabel-name-disclaimer":"(Will be public)","aadc-textlabel-signup-disclaimer":"By creating an account you accept the {link-tou} and have read the {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Your name will be public, use a nickname.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 536:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Vaya, algo ha salido mal. Inténtalo de nuevo más tarde.","notification-nointernetconnection":"Sin conexión. Conéctate e inténtalo de nuevo.","link-pp":"Política de privacidad","aadc-title-textlabel":"¿Cuál es tu fecha de nacimiento?","aadc-subtitle-textlabel":"Te lo preguntamos para asegurarnos de ofrecerte la mejor experiencia posible.","aadc-year-inline":"Año","aadc-month-inline":"Mes","aadc-day":"Día","aadc-year-hint":"AAAA","aadc-day-hint":"DD","aadc-continue-button":"CONTINUAR","aadc-legal-disclaimer-textlabel":"Tu fecha de nacimiento no se hará pública ni se compartirá con terceros.","aadc-month-jan":"Enero","aadc-month-feb":"Febrero","aadc-month-mar":"Marzo","aadc-month-apr":"Abril","aadc-month-may":"Mayo","aadc-month-jun":"Junio","aadc-month-jul":"Julio","aadc-month-aug":"Agosto","aadc-month-sep":"Septiembre","aadc-month-oct":"Octubre","aadc-month-nov":"Noviembre","aadc-month-dec":"Diciembre","aadc-block-title":"Vaya, parece que no puedes jugar ahora mismo","aadc-block-subtitle-textdialog":"Lo sentimos, parece que no cumples los requisitos para jugar a este juego.","link-tou":"Términos y condiciones de uso","aadc-notification-badyear":"Introduce tu año de nacimiento con cuatro dígitos.","aadc-notification-emptyfield":"Se requiere el día, el mes y el año.","aadc-notification-validdate":"La fecha no es válida.","aadc-button-contactus":"Contactar","aadc-title-restricted":"Estás jugando a una versión limitada del juego","aadc-textlabel-contactus":"Si tienes cualquier pregunta, no dudes en","aadc-button-gotit":"Entendido","aadc-notification-timetravel":"Debes indicar el año en que naciste.","aadc-abb-jan":"ene","aadc-abb-feb":"feb","aadc-abb-mar":"mar","aadc-abb-apr":"abr","aadc-abb-may":"may","aadc-abb-jun":"jun","aadc-abb-july":"jul","aadc-abb-aug":"ago","aadc-abb-sep":"sep","aadc-abb-oct":"oct","aadc-abb-nov":"nov","aadc-abb-dec":"dic","aadc-textlabel-agegate-desc":"Es necesaria para poder adaptar la experiencia de juego a las regulaciones regionales.","aadc-textlabel-agegate":"No puedes acceder al juego en estos momentos debido a las regulaciones regionales.","aadc-block-subtitle2-texdialog":"Debido a las regulaciones regionales, algunas características se han desactivado.","aadc-block-subtitle3-texdialog":"No obstante, puedes activar dichas características en el juego.","aadc-texlabel-name-disclaimer":"(Será público)","aadc-textlabel-signup-disclaimer":"Al crear una cuenta aceptas los {link-tou} y debes haber leído la {link-pp}.","aadc-texlabel-name-disclaimer-edit":"El nombre que utilices será público, utiliza un apodo.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 147:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Ups, algo salió mal. Inténtalo de nuevo más tarde.","notification-nointernetconnection":"Sin conexión. Conéctate e inténtalo de nuevo.","link-pp":"Política de privacidad","aadc-title-textlabel":"¿Cuándo es tu cumpleaños?","aadc-subtitle-textlabel":"Te preguntamos la fecha de tu cumpleaños para poder ofrecerte la mejor experiencia posible.","aadc-year-inline":"Año","aadc-month-inline":"Mes","aadc-day":"Día","aadc-year-hint":"AÑO","aadc-day-hint":"DD","aadc-continue-button":"CONTINUAR","aadc-legal-disclaimer-textlabel":"La fecha de tu cumpleaños no se hará pública ni la compartiremos con terceras partes.","aadc-month-jan":"Enero","aadc-month-feb":"Febrero","aadc-month-mar":"Marzo","aadc-month-apr":"Abril","aadc-month-may":"Mayo","aadc-month-jun":"Junio","aadc-month-jul":"Julio","aadc-month-aug":"Agosto","aadc-month-sep":"Septiembre","aadc-month-oct":"Octubre","aadc-month-nov":"Noviembre","aadc-month-dec":"Diciembre","aadc-block-title":"¡Ups! Parece que no puedes jugar ahora","aadc-block-subtitle-textdialog":"Lo sentimos, parece que no eres apto para este juego.","link-tou":"Términos de uso","aadc-notification-badyear":"Escribe el año de nacimiento con 4 dígitos.","aadc-notification-emptyfield":"Se necesita año, mes y día.","aadc-notification-validdate":"La fecha de nacimiento no es válida.","aadc-button-contactus":"Contáctanos","aadc-title-restricted":"Ahora estás jugando una versión lite del juego","aadc-textlabel-contactus":"Si tienes alguna pregunta, por favor","aadc-button-gotit":"¡Entendido!","aadc-notification-timetravel":"La fecha de nacimiento debe ser el día en que naciste.","aadc-abb-jan":"En.","aadc-abb-feb":"Febr.","aadc-abb-mar":"Mzo.","aadc-abb-apr":"Abr.","aadc-abb-may":"My.","aadc-abb-jun":"Jun.","aadc-abb-july":"Jul.","aadc-abb-aug":"Agt.","aadc-abb-sep":"Sept.","aadc-abb-oct":"Oct.","aadc-abb-nov":"Nov.","aadc-abb-dec":"Dic.","aadc-textlabel-agegate-desc":"Necesitamos esta información para personalizar la experiencia de juego según las regulaciones de la región.","aadc-textlabel-agegate":"Lo sentimos, no puedes acceder al juego en estos momentos debido a las regulaciones de la región.","aadc-block-subtitle2-texdialog":"Desactivamos algunas funciones debido a las regulaciones de la región.","aadc-block-subtitle3-texdialog":"Sin embargo, podrás activar esas funciones dentro del juego.","aadc-texlabel-name-disclaimer":"(Será público)","aadc-textlabel-signup-disclaimer":"Cuando creas una cuenta, aceptas los {link-tou} y confirmas que leíste la {link-pp}.","aadc-texlabel-name-disclaimer-edit":"El nombre será público, usa un apodo.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 337:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Hups, jokin meni vikaan! Yritä myöhemmin uudelleen.","notification-nointernetconnection":"Ei verkkoyhteyttä. Luo yhteys ja yritä uudelleen.","link-pp":"Tietosuoja","aadc-title-textlabel":"Mikä syntymäpäiväsi on?","aadc-subtitle-textlabel":"Kysymme syntymäpäivääsi, jotta voimme tarjota parhaan mahdollisen pelikokemuksen.","aadc-year-inline":"Vuosi","aadc-month-inline":"Kuukausi","aadc-day":"Päivä","aadc-year-hint":"VVVV","aadc-day-hint":"PP","aadc-continue-button":"JATKA","aadc-legal-disclaimer-textlabel":"Syntymäaikaasi ei näytetä julkisesti tai jaeta millekään kolmannelle osapuolelle.","aadc-month-jan":"Tammikuu","aadc-month-feb":"Helmikuu","aadc-month-mar":"Maaliskuu","aadc-month-apr":"Huhtikuu","aadc-month-may":"Toukokuu","aadc-month-jun":"Kesäkuu","aadc-month-jul":"Heinäkuu","aadc-month-aug":"Elokuu","aadc-month-sep":"Syyskuu","aadc-month-oct":"Lokakuu","aadc-month-nov":"Marraskuu","aadc-month-dec":"Joulukuu","aadc-block-title":"Hups! Näyttää siltä, ettet voi pelata nyt.","aadc-block-subtitle-textdialog":"Pahoittelut, mutta sinulla ei nähtävästi ole kelpoisuutta tähän peliin.","link-tou":"Käyttöehdot","aadc-notification-badyear":"Syötä syntymävuotesi neljällä numerolla.","aadc-notification-emptyfield":"Vuosi, kuukausi ja päivä on annettava.","aadc-notification-validdate":"Syntymäaika vaikuttaa virheelliseltä päivämäärältä.","aadc-button-contactus":"Ota yhteyttä","aadc-title-restricted":"Pelaat nyt pelin kevytversiota","aadc-textlabel-contactus":"Jos sinulla on kysyttävää:","aadc-button-gotit":"Selvä!","aadc-notification-timetravel":"Syntymäajan on oltava oikea syntymäpäiväsi.","aadc-abb-jan":"tammik.","aadc-abb-feb":"helmik.","aadc-abb-mar":"maalisk.","aadc-abb-apr":"huhtik.","aadc-abb-may":"toukok.","aadc-abb-jun":"kesäk.","aadc-abb-july":"heinäk.","aadc-abb-aug":"elok.","aadc-abb-sep":"syysk.","aadc-abb-oct":"lokak.","aadc-abb-nov":"marrask.","aadc-abb-dec":"jouluk.","aadc-textlabel-agegate-desc":"Tämä vaaditaan, jotta voimme räätälöidä pelikokemuksen paikallisen lainsäädännön mukaiseksi.","aadc-textlabel-agegate":"Pahoittelut, mutta et voi käyttää peliä nyt paikallisen lainsäädännön perusteella.","aadc-block-subtitle2-texdialog":"Osa toiminnoista on poistettu käytöstä paikallisen lainsäädännön perusteella.","aadc-block-subtitle3-texdialog":"Voit silti ottaa nämä toiminnot käyttöön pelissä.","aadc-texlabel-name-disclaimer":"(Tämä on julkinen)","aadc-textlabel-signup-disclaimer":"{link-tou} on hyväksyttävä ja {link-pp} luettava. Tilin luomalla vahvistat hyväksyntäsi ja lukemisen.","aadc-texlabel-name-disclaimer-edit":"Nimesi tulee olemaan julkinen, joten käytä nimimerkkiä.","aadc-month-hint-short":"KK"}');

/***/ }),

/***/ 444:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Oups, il y a un problème. Veuillez réessayer plus tard.","notification-nointernetconnection":"Hors ligne. Réessayez avec une connexion internet.","link-pp":"Politique de confidentialité","aadc-title-textlabel":"Quelle est votre date de naissance ?","aadc-subtitle-textlabel":"Nous vous demandons votre date de naissance pour vous proposer la meilleure expérience possible.","aadc-year-inline":"Année","aadc-month-inline":"Mois","aadc-day":"Jour","aadc-year-hint":"AAAA","aadc-day-hint":"JJ","aadc-continue-button":"CONTINUER","aadc-legal-disclaimer-textlabel":"Votre date de naissance ne sera pas publiée ou partagée avec des tiers.","aadc-month-jan":"Janvier","aadc-month-feb":"Février","aadc-month-mar":"Mars","aadc-month-apr":"Avril","aadc-month-may":"Mai","aadc-month-jun":"Juin","aadc-month-jul":"Juillet","aadc-month-aug":"Août","aadc-month-sep":"Septembre","aadc-month-oct":"Octobre","aadc-month-nov":"Novembre","aadc-month-dec":"Décembre","aadc-block-title":"Oups ! Vous ne pouvez pas jouer pour l\'instant","aadc-block-subtitle-textdialog":"Désolé, on dirait que vous ne remplissez pas les conditions requises pour ce jeu.","link-tou":"Conditions d\'utilisation","aadc-notification-badyear":"Votre année de naissance doit comporter 4 chiffres.","aadc-notification-emptyfield":"L\'année, le mois et le jour sont requis.","aadc-notification-validdate":"Votre date de naissance ne semble pas valide.","aadc-button-contactus":"Nous contacter","aadc-title-restricted":"Vous jouez actuellement à une version allégée du jeu.","aadc-textlabel-contactus":"Pour toute question, veuillez","aadc-button-gotit":"Compris !","aadc-notification-timetravel":"La date doit correspondre à votre date de naissance.","aadc-abb-jan":"Jan.","aadc-abb-feb":"Fév.","aadc-abb-mar":"Mars","aadc-abb-apr":"Avr.","aadc-abb-may":"Mai","aadc-abb-jun":"Juin","aadc-abb-july":"Juill.","aadc-abb-aug":"Août","aadc-abb-sep":"Sept.","aadc-abb-oct":"Oct.","aadc-abb-nov":"Nov.","aadc-abb-dec":"Déc.","aadc-textlabel-agegate-desc":"Cette information est nécessaire pour personnaliser l\'expérience de jeu dans le cadre des réglementations régionales.","aadc-textlabel-agegate":"Désolé, mais vous ne pouvez pas accéder au jeu pour le moment en raison des réglementations régionales.","aadc-block-subtitle2-texdialog":"En raison des réglementations régionales, certaines fonctions ont été désactivées.","aadc-block-subtitle3-texdialog":"Vous pourrez toujours activer ces fonctions dans le jeu.","aadc-texlabel-name-disclaimer":"(ce nom sera public)","aadc-textlabel-signup-disclaimer":"En créant un compte, vous acceptez les {link-tou} et vous confirmez avoir lu la {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Votre nom sera public, utilisez un pseudo.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 990:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Ops, si è verificato un errore. Riprova più tardi.","notification-nointernetconnection":"Sei offline. Connettiti a Internet e riprova.","link-pp":"Informativa sulla privacy","aadc-title-textlabel":"Inserisci la tua data di nascita.","aadc-subtitle-textlabel":"Chiediamo la tua data di nascita per assicurarci di offrirti la migliore esperienza possibile.","aadc-year-inline":"Anno","aadc-month-inline":"Mese","aadc-day":"Giorno","aadc-year-hint":"AAAA","aadc-day-hint":"GG","aadc-continue-button":"CONTINUA","aadc-legal-disclaimer-textlabel":"La tua data di nascita non sarà resa pubblica, né condivisa con terzi.","aadc-month-jan":"Gennaio","aadc-month-feb":"Febbraio","aadc-month-mar":"Marzo","aadc-month-apr":"Aprile","aadc-month-may":"Maggio","aadc-month-jun":"Giugno","aadc-month-jul":"Luglio","aadc-month-aug":"Agosto","aadc-month-sep":"Settembre","aadc-month-oct":"Ottobre","aadc-month-nov":"Novembre","aadc-month-dec":"Dicembre","aadc-block-title":"Ops! Sembra che tu non possa giocare ora.","aadc-block-subtitle-textdialog":"Purtroppo, sembra che tu non possa giocare a questo gioco.","link-tou":"Condizioni di utilizzo","aadc-notification-badyear":"Immetti l\'anno di nascita a 4 cifre.","aadc-notification-emptyfield":"Sono necessari anno, mese e giorno.","aadc-notification-validdate":"La data di nascita specificata non è valida.","aadc-button-contactus":"Contattaci","aadc-title-restricted":"Stai utilizzando una versione lite del gioco","aadc-textlabel-contactus":"In caso di domande","aadc-button-gotit":"OK!","aadc-notification-timetravel":"La data di nascita deve essere corretta.","aadc-abb-jan":"gen.","aadc-abb-feb":"feb.","aadc-abb-mar":"mar.","aadc-abb-apr":"apr.","aadc-abb-may":"mag.","aadc-abb-jun":"giu.","aadc-abb-july":"lug.","aadc-abb-aug":"ago.","aadc-abb-sep":"set.","aadc-abb-oct":"ott.","aadc-abb-nov":"nov.","aadc-abb-dec":"dic.","aadc-textlabel-agegate-desc":"Questo dato ci serve per poter adattare l\'esperienza di gioco in base ai regolamenti regionali.","aadc-textlabel-agegate":"Purtroppo, non puoi accedere al gioco in questo momento a causa dei regolamenti regionali.","aadc-block-subtitle2-texdialog":"A causa dei regolamenti regionali, alcune funzionalità sono state disattivate.","aadc-block-subtitle3-texdialog":"Potrai comunque attivare queste funzionalità dall\'interno del gioco.","aadc-texlabel-name-disclaimer":"(sarà pubblico)","aadc-textlabel-signup-disclaimer":"Creando un account, accetti le nostre {link-tou} e confermi di aver letto l\'{link-pp}.","aadc-texlabel-name-disclaimer-edit":"Il tuo nome sarà pubblico, usa un nickname.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 99:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"エラーが発生しました。後ほどもう一度お試しください。","notification-nointernetconnection":"インターネットに再接続してもう一度お試しください。","link-pp":"プライバシーポリシー","aadc-title-textlabel":"年齢確認","aadc-subtitle-textlabel":"お客様に最高のゲーム体験をお届けするため、生年月日の入力をお願いしております。","aadc-year-inline":"年","aadc-month-inline":"月","aadc-day":"日","aadc-year-hint":"YYYY","aadc-day-hint":"DD","aadc-continue-button":"次へ","aadc-legal-disclaimer-textlabel":"お客様の生年月日情報が公開されたり、第三者に共有されることはありません。","aadc-month-jan":"1","aadc-month-feb":"2","aadc-month-mar":"3","aadc-month-apr":"4","aadc-month-may":"5","aadc-month-jun":"6","aadc-month-jul":"7","aadc-month-aug":"8","aadc-month-sep":"9","aadc-month-oct":"10","aadc-month-nov":"11","aadc-month-dec":"12","aadc-block-title":"現在プレイできません","aadc-block-subtitle-textdialog":"申し訳ございません。お客様はこのゲームの対象年齢に達していないようです。","link-tou":"利用規約","aadc-notification-badyear":"生まれた年を西暦で入力して下さい。","aadc-notification-emptyfield":"生まれた年、月、日をもれなく入力して下さい。","aadc-notification-validdate":"生年月日の日付が正しくないようです。","aadc-button-contactus":"お問い合わせ","aadc-title-restricted":"ご利用のゲームはライト版（軽量版）です","aadc-textlabel-contactus":"​ご不明な点がありましたら、サポート窓口までお問い合わせください","aadc-button-gotit":"OK","aadc-notification-timetravel":"生年月日を正しく入力して下さい。","aadc-abb-jan":"1","aadc-abb-feb":"2","aadc-abb-mar":"3","aadc-abb-apr":"4","aadc-abb-may":"5","aadc-abb-jun":"6","aadc-abb-july":"7","aadc-abb-aug":"8","aadc-abb-sep":"9","aadc-abb-oct":"10","aadc-abb-nov":"11","aadc-abb-dec":"12","aadc-textlabel-agegate-desc":"地域の規制範囲内でゲームプレイをお楽しみいただくため、生年月日の入力をお願いしております。","aadc-textlabel-agegate":"地域の規制により、現在ゲームにアクセスできません。","aadc-block-subtitle2-texdialog":"地域の規制により、一部の機能がオフになりました。","aadc-block-subtitle3-texdialog":"ゲーム内でこの機能を再びオンにすることも可能です。","aadc-texlabel-name-disclaimer":"（公開されます）","aadc-textlabel-signup-disclaimer":"アカウントを作成することにより、{link-tou}に同意し{link-pp}を確認したものとさせていただきます。","aadc-texlabel-name-disclaimer-edit":"名前は公開されますのでニックネームをお使い下さい。","aadc-month-hint-short":"月"}');

/***/ }),

/***/ 599:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"이런, 문제가 발생했어요. 나중에 다시 시도하세요.","notification-nointernetconnection":"오프라인 상태입니다. 인터넷에 연결하고 다시 시도하세요.","link-pp":"개인정보 보호정책","aadc-title-textlabel":"생일이 언제인가요?","aadc-subtitle-textlabel":"최적의 경험을 제공해드리기 위해 생일을 확인하고 있습니다.","aadc-year-inline":"년","aadc-month-inline":"월","aadc-day":"일","aadc-year-hint":"YYYY","aadc-day-hint":"DD","aadc-continue-button":"계속하기","aadc-legal-disclaimer-textlabel":"생일 정보는 공개되거나 외부로 공유되지 않습니다.","aadc-month-jan":"1월","aadc-month-feb":"2월","aadc-month-mar":"3월","aadc-month-apr":"4월","aadc-month-may":"5월","aadc-month-jun":"6월","aadc-month-jul":"7월","aadc-month-aug":"8월","aadc-month-sep":"9월","aadc-month-oct":"10월","aadc-month-nov":"11월","aadc-month-dec":"12월","aadc-block-title":"앗! 지금은 플레이할 수 없는 것 같아요","aadc-block-subtitle-textdialog":"죄송합니다, 이 게임 플레이를 위한 조건이 충족되지 않는 것 같습니다.","link-tou":"사용 약관","aadc-notification-badyear":"출생 연도를 4자리로 입력해주세요.","aadc-notification-emptyfield":"년, 월, 일이 모두 필요합니다.","aadc-notification-validdate":"생일 날짜가 올바르지 않은 것 같습니다.","aadc-button-contactus":"문의하기","aadc-title-restricted":"게임의 라이트 버전을 이용하고 있습니다.","aadc-textlabel-contactus":"문제가 있을 경우 문의해주시기 바랍니다.","aadc-button-gotit":"확인","aadc-notification-timetravel":"생일은 본인이 태어난 날짜여야 합니다.","aadc-abb-jan":"1월","aadc-abb-feb":"2월","aadc-abb-mar":"3월","aadc-abb-apr":"4월","aadc-abb-may":"5월","aadc-abb-jun":"6월","aadc-abb-july":"7월","aadc-abb-aug":"8월","aadc-abb-sep":"9월","aadc-abb-oct":"10월","aadc-abb-nov":"11월","aadc-abb-dec":"12월","aadc-textlabel-agegate-desc":"이 정보는 지역 규정에 맞춘 게임 경험을 제공하기 위해 필요합니다.","aadc-textlabel-agegate":"죄송합니다, 지금은 지역 규정으로 인해 게임을 이용할 수 없습니다.","aadc-block-subtitle2-texdialog":"지역 규정으로 인해 일부 기능이 비활성화되었습니다.","aadc-block-subtitle3-texdialog":"게임에서 해당 기능을 직접 켤 수 있습니다.","aadc-texlabel-name-disclaimer":"(공개됨)","aadc-textlabel-signup-disclaimer":"계정을 만들면 {link-tou}을 수락하고 {link-pp}을 읽었음을 확정합니다.","aadc-texlabel-name-disclaimer-edit":"이름은 공개됩니다. 별명을 사용하세요.","aadc-month-hint-short":"월"}');

/***/ }),

/***/ 709:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Oeps, er ging iets mis. Probeer het later opnieuw.","notification-nointernetconnection":"Je bent offline. Maak verbinding met het internet.","link-pp":"Privacybeleid","aadc-title-textlabel":"Wanneer ben je geboren?","aadc-subtitle-textlabel":"We vragen om je geboortedatum om je de best mogelijke ervaring te bieden.","aadc-year-inline":"Jaar","aadc-month-inline":"Maand","aadc-day":"Dag","aadc-year-hint":"JJJJ","aadc-day-hint":"DD","aadc-continue-button":"DOORGAAN","aadc-legal-disclaimer-textlabel":"Je geboortedatum wordt niet openbaar gemaakt of gedeeld met derden.","aadc-month-jan":"Januari","aadc-month-feb":"Februari","aadc-month-mar":"Maart","aadc-month-apr":"April","aadc-month-may":"Mei","aadc-month-jun":"Juni","aadc-month-jul":"Juli","aadc-month-aug":"Augustus","aadc-month-sep":"September","aadc-month-oct":"Oktober","aadc-month-nov":"November","aadc-month-dec":"December","aadc-block-title":"Oeps! Het lijkt erop dat je nu niet kunt spelen","aadc-block-subtitle-textdialog":"Sorry, het lijkt erop dat je niet in aanmerking komt voor dit spel.","link-tou":"Gebruiksvoorwaarden","aadc-notification-badyear":"Geef je geboortejaar op (4 cijfers).","aadc-notification-emptyfield":"Jaar, maand en dag zijn vereist.","aadc-notification-validdate":"De geboortedatum lijkt ongeldig.","aadc-button-contactus":"Contact opnemen","aadc-title-restricted":"Je speelt nu een lite-versie van het spel","aadc-textlabel-contactus":"Als je vragen hebt, kun je","aadc-button-gotit":"Begrepen!","aadc-notification-timetravel":"Geef de datum op waarop je bent geboren.","aadc-abb-jan":"Jan.","aadc-abb-feb":"Feb.","aadc-abb-mar":"Mrt.","aadc-abb-apr":"Apr.","aadc-abb-may":"Mei","aadc-abb-jun":"Juni","aadc-abb-july":"Juli","aadc-abb-aug":"Aug.","aadc-abb-sep":"Sept.","aadc-abb-oct":"Okt.","aadc-abb-nov":"Nov.","aadc-abb-dec":"Dec.","aadc-textlabel-agegate-desc":"Dit is vereist om de speelervaring af te stemmen op regionale voorschriften.","aadc-textlabel-agegate":"Sorry, je krijgt nu geen toegang tot het spel vanwege regionale voorschriften.","aadc-block-subtitle2-texdialog":"Vanwege regionale voorschriften zijn sommige functies uitgeschakeld.","aadc-block-subtitle3-texdialog":"Je kunt deze functies inschakelen in het spel.","aadc-texlabel-name-disclaimer":"(Openbaar)","aadc-textlabel-signup-disclaimer":"Door een account te maken, verklaar je dat je de {link-tou} accepteert en het {link-pp} hebt gelezen.","aadc-texlabel-name-disclaimer-edit":"Je naam is openbaar, gebruik een bijnaam.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 308:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Oi, det oppsto en feil. Prøv på nytt senere.","notification-nointernetconnection":"Ikke på nett. Koble til internett og prøv igjen.","link-pp":"Retningslinjer for personvern","aadc-title-textlabel":"Når fyller du år?","aadc-subtitle-textlabel":"Vi spør om fødselsdagen din for at du skal få en best mulig opplevelse.","aadc-year-inline":"År","aadc-month-inline":"Måned","aadc-day":"Dag","aadc-year-hint":"ÅÅÅÅ","aadc-day-hint":"DD","aadc-continue-button":"FORTSETT","aadc-legal-disclaimer-textlabel":"Fødselsdatoen din vises ikke offentlig og deles ikke med tredjeparter.","aadc-month-jan":"januar","aadc-month-feb":"februar","aadc-month-mar":"mars","aadc-month-apr":"april","aadc-month-may":"mai","aadc-month-jun":"juni","aadc-month-jul":"juli","aadc-month-aug":"august","aadc-month-sep":"september","aadc-month-oct":"oktober","aadc-month-nov":"november","aadc-month-dec":"desember","aadc-block-title":"Oi! Du kan visst ikke spille nå","aadc-block-subtitle-textdialog":"Beklager, du kan visst ikke bruke dette spillet.","link-tou":"Bruksvilkår","aadc-notification-badyear":"Oppgi fødselsåret ditt med 4 siffer.","aadc-notification-emptyfield":"Du må skrive inn år, måned og dag.","aadc-notification-validdate":"Fødselsdatoen er visst ikke en gyldig dato.","aadc-button-contactus":"Kontakt oss","aadc-title-restricted":"Du spiller nå en «lett» utgave av spillet","aadc-textlabel-contactus":"Hvis det er noe du lurer på, kan du","aadc-button-gotit":"Skjønner!","aadc-notification-timetravel":"Bursdagen må være fødselsdatoen din.","aadc-abb-jan":"jan.","aadc-abb-feb":"feb.","aadc-abb-mar":"mars","aadc-abb-apr":"apr.","aadc-abb-may":"mai","aadc-abb-jun":"juni","aadc-abb-july":"juli","aadc-abb-aug":"aug.","aadc-abb-sep":"sep.","aadc-abb-oct":"okt.","aadc-abb-nov":"nov.","aadc-abb-dec":"des.","aadc-textlabel-agegate-desc":"Vi trenger dette for å skreddersy opplevelsen i henhold til lokale regelverk.","aadc-textlabel-agegate":"Beklager, men du kan ikke spille spillet nå på grunn av lokale regelverk.","aadc-block-subtitle2-texdialog":"Enkelte funksjoner er slått av på grunn av lokale regelverk.","aadc-block-subtitle3-texdialog":"Du kan fortsatt slå disse funksjonene på i spillet.","aadc-texlabel-name-disclaimer":"(Vil være offentlig)","aadc-textlabel-signup-disclaimer":"Hvis du oppretter en konto, betyr det at du samtykker i {link-tou} og har lest {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Navnet ditt vil være offentlig, så bruk et kallenavn.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 13:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Opa! Algo deu errado, tente novamente mais tarde!","notification-nointernetconnection":"Você está offline. Conecte-se e tente novamente.","link-pp":"Política de Privacidade","aadc-title-textlabel":"Quando é seu aniversário?","aadc-subtitle-textlabel":"Perguntamos quando é seu aniversário para oferecer a melhor experiência possível.","aadc-year-inline":"Ano","aadc-month-inline":"Mês","aadc-day":"Dia","aadc-year-hint":"AAAA","aadc-day-hint":"DD","aadc-continue-button":"CONTINUAR","aadc-legal-disclaimer-textlabel":"Sua data de nascimento não é um dado público e não é compartilhada com terceiros.","aadc-month-jan":"janeiro","aadc-month-feb":"fevereiro","aadc-month-mar":"março","aadc-month-apr":"abril","aadc-month-may":"maio","aadc-month-jun":"junho","aadc-month-jul":"julho","aadc-month-aug":"agosto","aadc-month-sep":"setembro","aadc-month-oct":"outubro","aadc-month-nov":"novembro","aadc-month-dec":"dezembro","aadc-block-title":"Ops! Parece que você não pode jogar por enquanto.","aadc-block-subtitle-textdialog":"Sentimos muito, não é permitido que você jogue este jogo.","link-tou":"Termos de Uso","aadc-notification-badyear":"Digite os 4 números do ano de nascimento.","aadc-notification-emptyfield":"Ano, mês e dia são necessários.","aadc-notification-validdate":"Data de nascimento inválida.","aadc-button-contactus":"Fale conosco","aadc-title-restricted":"Agora você está jogando a versão lite do jogo","aadc-textlabel-contactus":"Em caso de dúvidas,","aadc-button-gotit":"Entendido!","aadc-notification-timetravel":"A data de nascimento precisa ser o dia em que você nasceu.","aadc-abb-jan":"jan.","aadc-abb-feb":"fev.","aadc-abb-mar":"mar.","aadc-abb-apr":"abr.","aadc-abb-may":"maio","aadc-abb-jun":"junho","aadc-abb-july":"julho","aadc-abb-aug":"ago.","aadc-abb-sep":"set.","aadc-abb-oct":"out.","aadc-abb-nov":"nov.","aadc-abb-dec":"dez.","aadc-textlabel-agegate-desc":"Isto é necessário para que possamos oferecer a melhor experiência de jogo possível dentro das leis de sua região.","aadc-textlabel-agegate":"Sentimos muito, você não pode acessar este jogo no momento devido às leis de sua região.","aadc-block-subtitle2-texdialog":"Devido às leis de sua região, alguns recursos do jogo foram desativados.","aadc-block-subtitle3-texdialog":"Ainda será possível ativá-los de dentro do jogo.","aadc-texlabel-name-disclaimer":"(Será público)","aadc-textlabel-signup-disclaimer":"Ao criar uma conta você aceita os aceita os {link-tou} e declara que leu a {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Seu nome será público, use um apelido.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 825:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Ups! Ceva nu a mers bine! Încearcă din nou mai târziu.","notification-nointernetconnection":"Ești offline. Conectează-te întâi la internet.","link-pp":"Politică de confidențialitate","aadc-title-textlabel":"Care este data nașterii tale?","aadc-subtitle-textlabel":"Te întrebăm despre data nașterii pentru a ne asigura că îți oferim cea mai bună experiență posibilă.","aadc-year-inline":"An","aadc-month-inline":"Lună","aadc-day":"Zi","aadc-year-hint":"AAAA","aadc-day-hint":"ZZ","aadc-continue-button":"CONTINUĂ","aadc-legal-disclaimer-textlabel":"Data nașterii nu va fi publică și nici divulgată vreunei terțe părți.","aadc-month-jan":"Ianuarie","aadc-month-feb":"Februarie","aadc-month-mar":"Martie","aadc-month-apr":"Aprilie","aadc-month-may":"Mai","aadc-month-jun":"Iunie","aadc-month-jul":"Iulie","aadc-month-aug":"August","aadc-month-sep":"Septembrie","aadc-month-oct":"Octombrie","aadc-month-nov":"Noiembrie","aadc-month-dec":"Decembrie","aadc-block-title":"Hopa! Se pare că nu te poți juca momentan","aadc-block-subtitle-textdialog":"Ne pare rău, se pare că nu ești eligibil(ă) pentru acest joc.","link-tou":"Condiții de utilizare","aadc-notification-badyear":"Introdu anul nașterii din 4 cifre.","aadc-notification-emptyfield":"Anul, luna și data sunt toate obligatorii.","aadc-notification-validdate":"Data nașterii nu pare să fie o dată validă.","aadc-button-contactus":"Contactează-ne","aadc-title-restricted":"Acum te joci o versiune limitată a jocului","aadc-textlabel-contactus":"Dacă ai întrebări,","aadc-button-gotit":"Am înțeles!","aadc-notification-timetravel":"Data nașterii trebuie să fie data când te-ai născut.","aadc-abb-jan":"Ian.","aadc-abb-feb":"Feb.","aadc-abb-mar":"Mar.","aadc-abb-apr":"Apr.","aadc-abb-may":"Mai","aadc-abb-jun":"Iun.","aadc-abb-july":"Iul.","aadc-abb-aug":"Aug.","aadc-abb-sep":"Sept.","aadc-abb-oct":"Oct.","aadc-abb-nov":"Noi.","aadc-abb-dec":"Dec.","aadc-textlabel-agegate-desc":"Avem nevoie de această informație pentru a-ți ajusta experiența de joc conform reglementărilor regionale.","aadc-textlabel-agegate":"Ne pare rău, dar nu poți accesa jocul momentan din cauza reglementărilor regionale.","aadc-block-subtitle2-texdialog":"Din cauza reglementărilor regionale, anumite caracteristici au fost dezactivate.","aadc-block-subtitle3-texdialog":"Vei putea totuși să activezi acele caracteristici în joc.","aadc-texlabel-name-disclaimer":"(Va fi public)","aadc-textlabel-signup-disclaimer":"Prin crearea unui cont, accepți {link-tou} și ai citit {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Numele tău va fi public, folosește o poreclă.","aadc-month-hint-short":"LL"}');

/***/ }),

/***/ 634:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Что-то пошло не так. Повторите попытку позже.","notification-nointernetconnection":"Нет связи. Подключитесь к Интернету и повторите.","link-pp":"Политика конфиденциальности","aadc-title-textlabel":"Когда у тебя День рождения?","aadc-subtitle-textlabel":"Мы спрашиваем, чтобы тебя поздравить.","aadc-year-inline":"Год","aadc-month-inline":"Месяц","aadc-day":"День","aadc-year-hint":"ГГГГ","aadc-day-hint":"ДД","aadc-continue-button":"ПРОДОЛЖИТЬ","aadc-legal-disclaimer-textlabel":"Мы никому не расскажем, когда у тебя День рождения.","aadc-month-jan":"января","aadc-month-feb":"февраля","aadc-month-mar":"марта","aadc-month-apr":"апреля","aadc-month-may":"мая","aadc-month-jun":"июня","aadc-month-jul":"июля","aadc-month-aug":"августа","aadc-month-sep":"сентября","aadc-month-oct":"октября","aadc-month-nov":"ноября","aadc-month-dec":"декабря","aadc-block-title":"Ой! Похоже, ты не можешь играть.","aadc-block-subtitle-textdialog":"Прости, ты не можешь играть в эту игру.","link-tou":"Условия пользования","aadc-notification-badyear":"Добавь год рождения — 4 цифры.","aadc-notification-emptyfield":"Нужно указать год, месяц и день.","aadc-notification-validdate":"Кажется, это неправильная дата.","aadc-button-contactus":"Свяжитесь с нами","aadc-title-restricted":"Вы играете в облегченную версию игры.","aadc-textlabel-contactus":"Если у вас есть вопросы,","aadc-button-gotit":"Ясно!","aadc-notification-timetravel":"Дата рождения – день, когда вы родились.","aadc-abb-jan":"янв.","aadc-abb-feb":"фев.","aadc-abb-mar":"мар.","aadc-abb-apr":"апр.","aadc-abb-may":"мая","aadc-abb-jun":"июня","aadc-abb-july":"июля","aadc-abb-aug":"авг.","aadc-abb-sep":"сен.","aadc-abb-oct":"окт.","aadc-abb-nov":"нояб.","aadc-abb-dec":"дек.","aadc-textlabel-agegate-desc":"Это необходимо, чтобы мы могли изменить игру в соответствии с местным законодательством.","aadc-textlabel-agegate":"К сожалению, в соответствии с местным законодательством вы не можете войти в игру.","aadc-block-subtitle2-texdialog":"В соответствии с местным законодательством некоторые функции отключены.","aadc-block-subtitle3-texdialog":"Вы можете включить их в игре вручную.","aadc-texlabel-name-disclaimer":"(Общедоступная информация)","aadc-textlabel-signup-disclaimer":"Создавая учетную запись, вы соглашаетесь с тем, что {link-tou} и {link-pp} вам знакомы, и вы с ними согласны.","aadc-texlabel-name-disclaimer-edit":"Придумайте себе псевдоним, так его могут видеть все.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 760:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Något gick fel. Försök igen senare.","notification-nointernetconnection":"Offline. Anslut till internet och försök igen.","link-pp":"Sekretesspolicy","aadc-title-textlabel":"Vad är ditt födelsedatum?","aadc-subtitle-textlabel":"Vi frågar efter ditt födelsedatum för att säkerställa att du får bästa möjliga upplevelse.","aadc-year-inline":"År","aadc-month-inline":"Månad","aadc-day":"Dag","aadc-year-hint":"ÅÅÅÅ","aadc-day-hint":"DD","aadc-continue-button":"FORTSÄTT","aadc-legal-disclaimer-textlabel":"Ditt födelsedatum offentliggörs inte och delas inte heller med tredje part.","aadc-month-jan":"januari","aadc-month-feb":"februari","aadc-month-mar":"mars","aadc-month-apr":"april","aadc-month-may":"maj","aadc-month-jun":"juni","aadc-month-jul":"juli","aadc-month-aug":"augusti","aadc-month-sep":"september","aadc-month-oct":"oktober","aadc-month-nov":"november","aadc-month-dec":"december","aadc-block-title":"Hoppsan, det verkar som att du inte kan spela!","aadc-block-subtitle-textdialog":"Du kan tyvärr inte spela det här spelet.","link-tou":"Användarvillkor","aadc-notification-badyear":"Ange ditt födelseår (4 siffror).","aadc-notification-emptyfield":"Du måste ange både år, månad och dag.","aadc-notification-validdate":"Ogiltigt födelsedatum.","aadc-button-contactus":"Kontakta oss","aadc-title-restricted":"Du spelar just nu en avskalad version av spelet.","aadc-textlabel-contactus":"Har du några frågor?","aadc-button-gotit":"Okej!","aadc-notification-timetravel":"Du måste ange ditt riktiga födelsedatum.","aadc-abb-jan":"jan","aadc-abb-feb":"feb","aadc-abb-mar":"mars","aadc-abb-apr":"april","aadc-abb-may":"maj","aadc-abb-jun":"juni","aadc-abb-july":"juli","aadc-abb-aug":"aug","aadc-abb-sep":"sept","aadc-abb-oct":"okt","aadc-abb-nov":"nov","aadc-abb-dec":"dec","aadc-textlabel-agegate-desc":"Det här är obligatoriskt för att vi ska kunna skräddarsy spelupplevelsen efter regionala bestämmelser.","aadc-textlabel-agegate":"På grund av regionala bestämmelser kan du tyvärr inte komma åt spelet just nu.","aadc-block-subtitle2-texdialog":"På grund av regionala bestämmelser har vissa funktioner avaktiverats.","aadc-block-subtitle3-texdialog":"Du kan fortfarande välja att aktivera funktionerna inne i spelet.","aadc-texlabel-name-disclaimer":"(Blir offentligt)","aadc-textlabel-signup-disclaimer":"Genom att skapa ett konto godkänner du {link-tou} och har läst {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Ditt namn blir offentligt. Använd ett smeknamn.","aadc-month-hint-short":"MM"}');

/***/ }),

/***/ 199:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"อ๊ะ... มีสิ่งผิดปกติเกิดขึ้น โปรดลองอีกครั้งภายหลัง","notification-nointernetconnection":"คุณออฟไลน์อยู่ เชื่อมต่ออินเทอร์เน็ตแล้วลองใหม่","link-pp":"นโยบายความเป็นส่วนตัว","aadc-title-textlabel":"คุณเกิดเมื่อไหร่?","aadc-subtitle-textlabel":"เราถามวันเกิดของคุณเพื่อให้แน่ใจว่าเรามอบประสบการณ์ที่ดีที่สุดเท่าที่เป็นไปได้ให้แก่คุณ","aadc-year-inline":"ปี","aadc-month-inline":"เดือน","aadc-day":"วัน","aadc-year-hint":"ปปปป","aadc-day-hint":"วว","aadc-continue-button":"ดำเนินการต่อ","aadc-legal-disclaimer-textlabel":"วันเกิดของคุณจะไม่เปิดเผยต่อสาธารณะหรือแบ่งปันให้บุคคลภายนอกใดๆ","aadc-month-jan":"มกราคม","aadc-month-feb":"กุมภาพันธ์","aadc-month-mar":"มีนาคม","aadc-month-apr":"เมษายน","aadc-month-may":"พฤษภาคม","aadc-month-jun":"มิถุนายน","aadc-month-jul":"กรกฎาคม","aadc-month-aug":"สิงหาคม","aadc-month-sep":"กันยายน","aadc-month-oct":"ตุลาคม","aadc-month-nov":"พฤศจิกายน","aadc-month-dec":"ธันวาคม","aadc-block-title":"อ๊ะ! ดูเหมือนคุณจะไม่สามารถเล่นได้ตอนนี้","aadc-block-subtitle-textdialog":"ขออภัย ดูเหมือนว่าคุณจะไม่มีสิทธิ์สำหรับเกมนี้","link-tou":"ข้อกำหนดการใช้","aadc-notification-badyear":"โปรดกรอกปีเกิดเป็นเลข 4 หลัก","aadc-notification-emptyfield":"จำเป็นต้องกรอกทั้งปี เดือน และวัน","aadc-notification-validdate":"วันเกิดนี้ดูเหมือนไม่ถูกต้อง","aadc-button-contactus":"ติดต่อเรา","aadc-title-restricted":"คุณกำลังเล่นเกมเวอร์ชัน Lite อยู่ตอนนี้","aadc-textlabel-contactus":"หากคุณมีคำถามใดๆ กรุณา","aadc-button-gotit":"เข้าใจแล้ว!","aadc-notification-timetravel":"วันเกิดต้องเป็นวันที่คุณเกิดจริง","aadc-abb-jan":"ม.ค.","aadc-abb-feb":"ก.พ.","aadc-abb-mar":"มี.ค.","aadc-abb-apr":"เม.ย.","aadc-abb-may":"พ.ค.","aadc-abb-jun":"มิ.ย.","aadc-abb-july":"ก.ค.","aadc-abb-aug":"ส.ค.","aadc-abb-sep":"ก.ย.","aadc-abb-oct":"ต.ค.","aadc-abb-nov":"พ.ย.","aadc-abb-dec":"ธ.ค.","aadc-textlabel-agegate-desc":"นี่เป็นข้อมูลที่จำเป็นเพื่อให้เราสามารถปรับแต่งประสบการณ์การเล่นให้เป็นไปตามข้อบังคับของภูมิภาคได้","aadc-textlabel-agegate":"ขออภัย คุณไม่สามารถเข้าสู่เกมได้ในขณะนี้เนื่องจากข้อบังคับของภูมิภาค","aadc-block-subtitle2-texdialog":"เนื่องจากข้อบังคับของภูมิภาค ทำให้บางคุณสมบัติถูกปิด","aadc-block-subtitle3-texdialog":"คุณจะยังสามารถเปิดคุณสมบัติเหล่านั้นได้ในเกม","aadc-texlabel-name-disclaimer":"(จะแสดงต่อสาธารณะ)","aadc-textlabel-signup-disclaimer":"การสร้างบัญชีจะถือว่าคุณยอมรับ {link-tou} และได้อ่าน {link-pp} แล้ว","aadc-texlabel-name-disclaimer-edit":"ชื่อของคุณจะแสดงต่อสาธารณะ โปรดใช้ชื่อเล่น","aadc-month-hint-short":"เเ"}');

/***/ }),

/***/ 986:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Eyvah, bir şeyler ters gitti. Lütfen sonra tekrar dene.","notification-nointernetconnection":"Çevrimdışısın. İnternete bağlan ve tekrar dene.","link-pp":"Gizlilik Politikası","aadc-title-textlabel":"Doğum günün ne zaman?","aadc-subtitle-textlabel":"Sana en iyi deneyimi sunduğumuzdan emin olmak için doğum gününü soruyoruz.","aadc-year-inline":"Yıl","aadc-month-inline":"Ay","aadc-day":"Gün","aadc-year-hint":"YYYY","aadc-day-hint":"GG","aadc-continue-button":"DEVAM ET","aadc-legal-disclaimer-textlabel":"Doğum tarihin herkese açık olmayacak ve herhangi bir üçüncü tarafla paylaşılmayacaktır.","aadc-month-jan":"Ocak","aadc-month-feb":"Şubat","aadc-month-mar":"Mart","aadc-month-apr":"Nisan","aadc-month-may":"Mayıs","aadc-month-jun":"Haziran","aadc-month-jul":"Temmuz","aadc-month-aug":"Ağustos","aadc-month-sep":"Eylül","aadc-month-oct":"Ekim","aadc-month-nov":"Kasım","aadc-month-dec":"Aralık","aadc-block-title":"Hay aksi! Görünüşe göre şu an oynayamazsın","aadc-block-subtitle-textdialog":"Maalesef bu oyun için uygun değilsin.","link-tou":"Kullanım Şartları","aadc-notification-badyear":"Lütfen doğum yılını 4 hane olarak gir.","aadc-notification-emptyfield":"Yıl, ay ve gün bölümlerinin hepsi gereklidir.","aadc-notification-validdate":"Doğum günü, geçerli bir tarih değil gibi görünüyor.","aadc-button-contactus":"Bize ulaş","aadc-title-restricted":"Oyunun lite sürümünü oynuyorsun.","aadc-textlabel-contactus":"Sormak istediğin bir şey var ise lütfen","aadc-button-gotit":"Anladım!","aadc-notification-timetravel":"Doğum günü, doğduğun tarih olmalıdır.","aadc-abb-jan":"Oca","aadc-abb-feb":"Şub","aadc-abb-mar":"Mar","aadc-abb-apr":"Nis","aadc-abb-may":"May","aadc-abb-jun":"Haz","aadc-abb-july":"Tem","aadc-abb-aug":"Ağu","aadc-abb-sep":"Eyl","aadc-abb-oct":"Eki","aadc-abb-nov":"Kas","aadc-abb-dec":"Ara","aadc-textlabel-agegate-desc":"Bu, oyun deneyimini bölgesel düzenlemelere göre ayarlayabilmemiz için gereklidir.","aadc-textlabel-agegate":"Üzgünüz, bölgesel düzenlemeler sebebiyle oyuna şu anda erişemezsin.","aadc-block-subtitle2-texdialog":"Bölgesel düzenlemeler sebebiyle bazı özellikler kapatıldı.","aadc-block-subtitle3-texdialog":"Oyundaki o özellikleri hâlâ açabileceksin.","aadc-texlabel-name-disclaimer":"(Herkese açık olacak)","aadc-textlabel-signup-disclaimer":"Bir hesap oluşturarak {link-tou} maddelerini kabul edersin ve {link-pp} belgesini okuduğunu onaylarsın.","aadc-texlabel-name-disclaimer-edit":"Adın herkese açık olacak, bu yüzden rumuz kullan.","aadc-month-hint-short":"Ay"}');

/***/ }),

/***/ 733:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"Rất tiếc, có điều gì đó sai sót. Vui lòng thử lại sau.","notification-nointernetconnection":"Bạn đang offline. Hãy kết nối Internet và thử lại.","link-pp":"Chính sách Quyền riêng tư","aadc-title-textlabel":"Sinh nhật của bạn là khi nào?","aadc-subtitle-textlabel":"Chúng tôi hỏi sinh nhật của bạn để đảm bảo rằng chúng tôi mang đến cho bạn trải nghiệm tốt nhất có thể.","aadc-year-inline":"Năm","aadc-month-inline":"Tháng","aadc-day":"Ngày","aadc-year-hint":"YYYY","aadc-day-hint":"DD","aadc-continue-button":"TIẾP TỤC","aadc-legal-disclaimer-textlabel":"Ngày sinh của bạn sẽ không được công khai, cũng như không được chia sẻ với bất kỳ bên thứ ba nào.","aadc-month-jan":"Tháng 1","aadc-month-feb":"Tháng 2","aadc-month-mar":"Tháng 3","aadc-month-apr":"Tháng 4","aadc-month-may":"Tháng 5","aadc-month-jun":"Tháng 6","aadc-month-jul":"Tháng 7","aadc-month-aug":"Tháng 8","aadc-month-sep":"Tháng 9","aadc-month-oct":"Tháng 10","aadc-month-nov":"Tháng 11","aadc-month-dec":"Tháng 12","aadc-block-title":"Ôi! Có vẻ như bạn không thể chơi bây giờ","aadc-block-subtitle-textdialog":"Rất tiếc, có vẻ như bạn không hội đủ điều kiện cho trò chơi này.","link-tou":"Điều khoản Sử dụng","aadc-notification-badyear":"Vui lòng nhập 4 chữ số năm sinh.","aadc-notification-emptyfield":"Bắt buộc phải có đầy đủ năm, tháng và ngày.","aadc-notification-validdate":"Ngày sinh dường như không hợp lệ.","aadc-button-contactus":"Liên hệ","aadc-title-restricted":"Bạn đang chơi phiên bản nhẹ của trò chơi","aadc-textlabel-contactus":"Nếu bạn có bất kỳ câu hỏi nào, vui lòng liên hệ","aadc-button-gotit":"Đã hiểu!","aadc-notification-timetravel":"Ngày sinh phải là ngày bạn ra đời.","aadc-abb-jan":"Tháng 1","aadc-abb-feb":"Tháng 2","aadc-abb-mar":"Tháng 3","aadc-abb-apr":"Tháng 4","aadc-abb-may":"Tháng 5","aadc-abb-jun":"Tháng 6","aadc-abb-july":"Tháng 7","aadc-abb-aug":"Tháng 8","aadc-abb-sep":"Tháng 9","aadc-abb-oct":"Tháng 10","aadc-abb-nov":"Tháng 11","aadc-abb-dec":"Tháng 12","aadc-textlabel-agegate-desc":"Điều này là bắt buộc để chúng tôi có thể tùy chỉnh trải nghiệm chơi trò chơi phù hợp với quy định của khu vực.","aadc-textlabel-agegate":"Rất tiếc, bạn không thể truy cập trò chơi vào lúc này do quy định của khu vực.","aadc-block-subtitle2-texdialog":"Do quy định của khu vực, một số tính năng đã bị tắt.","aadc-block-subtitle3-texdialog":"Bạn sẽ vẫn có thể bật các tính năng đó trong trò chơi.","aadc-texlabel-name-disclaimer":"(Sẽ hiển thị công khai)","aadc-textlabel-signup-disclaimer":"Bằng cách tạo tài khoản, bạn chấp nhận {link-tou} và đã đọc {link-pp}.","aadc-texlabel-name-disclaimer-edit":"Tên của bạn sẽ hiển thị công khai, hãy sử dụng biệt hiệu.","aadc-month-hint-short":"TT"}');

/***/ }),

/***/ 416:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"糟糕，發生錯誤！請稍後再試一次。","notification-nointernetconnection":"你尚未連上網路，請連上網際網路後再試一次。","link-pp":"隱私權政策","aadc-title-textlabel":"你的生日？","aadc-subtitle-textlabel":"詢問生日的目的是要提供你最好的體驗。","aadc-year-inline":"年","aadc-month-inline":"月","aadc-day":"日","aadc-year-hint":"西元年","aadc-day-hint":"日","aadc-continue-button":"繼續","aadc-legal-disclaimer-textlabel":"你的生日將不會公開，也不會和任何第三方團體分享。","aadc-month-jan":"1 月","aadc-month-feb":"2 月","aadc-month-mar":"3 月","aadc-month-apr":"4 月","aadc-month-may":"5 月","aadc-month-jun":"6 月","aadc-month-jul":"7 月","aadc-month-aug":"8 月","aadc-month-sep":"9 月","aadc-month-oct":"10 月","aadc-month-nov":"11 月","aadc-month-dec":"12 月","aadc-block-title":"哎呀！看來你現在無法遊玩","aadc-block-subtitle-textdialog":"抱歉，看來你尚未符合遊玩本遊戲的資格。","link-tou":"使用條款","aadc-notification-badyear":"請輸入​4 位數的​西元出生​年份。","aadc-notification-emptyfield":"年、月、日​皆為必填。","aadc-notification-validdate":"輸入的​生日無效。","aadc-button-contactus":"聯絡我們","aadc-title-restricted":"您正在​遊玩的是​本遊戲的​精簡版","aadc-textlabel-contactus":"如有任何​問題，​請您","aadc-button-gotit":"知道了！","aadc-notification-timetravel":"生日必須是​您出生的​日期。","aadc-abb-jan":"1 月","aadc-abb-feb":"2 月","aadc-abb-mar":"3 月","aadc-abb-apr":"4 月","aadc-abb-may":"5 月","aadc-abb-jun":"6 月","aadc-abb-july":"7 月","aadc-abb-aug":"8 月","aadc-abb-sep":"9 月","aadc-abb-oct":"10 月","aadc-abb-nov":"11 月","aadc-abb-dec":"12 月","aadc-textlabel-agegate-desc":"此為必填​項目，​我們會根據​此資訊​提供符合​區域性規範的​遊戲體驗。","aadc-textlabel-agegate":"抱歉，​基於區域性​規範的要求，​您現在無法​進入此遊戲。","aadc-block-subtitle2-texdialog":"基於區域性​規範的要求，​已關閉部分​遊戲功能。","aadc-block-subtitle3-texdialog":"您仍然能在​遊戲內開啟​這些功能。","aadc-texlabel-name-disclaimer":"（將會公開）","aadc-textlabel-signup-disclaimer":"建立帳號代表您接受{link-tou}且已閱讀{link-pp}。","aadc-texlabel-name-disclaimer-edit":"您的名字將會公開，請使用暱稱。","aadc-month-hint-short":"月"}');

/***/ }),

/***/ 595:
/***/ ((module) => {

"use strict";
module.exports = JSON.parse('{"notification-somethingwentwrong":"哎呀，出问题了，请稍后重试。","notification-nointernetconnection":"你掉线了，请接入网络并重试。","link-pp":"隐私政策","aadc-title-textlabel":"您的生日是几号？","aadc-subtitle-textlabel":"我们需要知道您的生日，从而为您提供最佳的游戏体验。","aadc-year-inline":"年","aadc-month-inline":"月","aadc-day":"日","aadc-year-hint":"年份","aadc-day-hint":"日期","aadc-continue-button":"继续","aadc-legal-disclaimer-textlabel":"我们不会公开或与任何第三方分享您的出生日期。","aadc-month-jan":"一月","aadc-month-feb":"二月","aadc-month-mar":"三月","aadc-month-apr":"四月","aadc-month-may":"五月","aadc-month-jun":"六月","aadc-month-jul":"七月","aadc-month-aug":"八月","aadc-month-sep":"九月","aadc-month-oct":"十月","aadc-month-nov":"十一月","aadc-month-dec":"十二月","aadc-block-title":"哎呀！你现在似乎无法开始游戏。","aadc-block-subtitle-textdialog":"抱歉，你似乎不满足游玩此游戏的条件。","link-tou":"使用条款","aadc-notification-badyear":"请输入出生年份，需 4 位数字。","aadc-notification-emptyfield":"年月日均需输入。","aadc-notification-validdate":"出生日期似乎无效","aadc-button-contactus":"联系我们","aadc-title-restricted":"您现在玩的是精简版游戏","aadc-textlabel-contactus":"如果您有任何疑问，请","aadc-button-gotit":"知道了！","aadc-notification-timetravel":"生日必须是您的出生日期。","aadc-abb-jan":"一月","aadc-abb-feb":"二月","aadc-abb-mar":"三月","aadc-abb-apr":"四月","aadc-abb-may":"五月","aadc-abb-jun":"六月","aadc-abb-july":"七月","aadc-abb-aug":"八月","aadc-abb-sep":"九月","aadc-abb-oct":"十月","aadc-abb-nov":"十一月","aadc-abb-dec":"十二月","aadc-textlabel-agegate-desc":"我们需要此信息根据区域法律法规来定制游戏体验。","aadc-textlabel-agegate":"抱歉，因区域法律法规限制，您暂时无法游玩此游戏。","aadc-block-subtitle2-texdialog":"因区域法律法规限制，部分功能已关闭。","aadc-block-subtitle3-texdialog":"您依然可以在游戏中开启那些功能。","aadc-texlabel-name-disclaimer":"（将公开展示）","aadc-textlabel-signup-disclaimer":"创建帐户即表明你接受{link-tou}并已仔细阅读了{link-pp}。","aadc-texlabel-name-disclaimer-edit":"你的名字将公开展示，请使用昵称。","aadc-month-hint-short":"月"}');

/***/ }),

/***/ 878:
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var map = {
	"./translations_da.json": 654,
	"./translations_de.json": 154,
	"./translations_en.json": 517,
	"./translations_es.json": 536,
	"./translations_es_MX.json": 147,
	"./translations_fi.json": 337,
	"./translations_fr.json": 444,
	"./translations_it.json": 990,
	"./translations_ja.json": 99,
	"./translations_ko.json": 599,
	"./translations_nl.json": 709,
	"./translations_no.json": 308,
	"./translations_pt_BR.json": 13,
	"./translations_ro.json": 825,
	"./translations_ru.json": 634,
	"./translations_sv.json": 760,
	"./translations_th.json": 199,
	"./translations_tr.json": 986,
	"./translations_vi.json": 733,
	"./translations_zh.json": 416,
	"./translations_zh_CN.json": 595
};


function webpackContext(req) {
	var id = webpackContextResolve(req);
	return __webpack_require__(id);
}
function webpackContextResolve(req) {
	if(!__webpack_require__.o(map, req)) {
		var e = new Error("Cannot find module '" + req + "'");
		e.code = 'MODULE_NOT_FOUND';
		throw e;
	}
	return map[req];
}
webpackContext.keys = function webpackContextKeys() {
	return Object.keys(map);
};
webpackContext.resolve = webpackContextResolve;
module.exports = webpackContext;
webpackContext.id = 878;

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = __webpack_modules__;
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/chunk loaded */
/******/ 	(() => {
/******/ 		var deferred = [];
/******/ 		__webpack_require__.O = (result, chunkIds, fn, priority) => {
/******/ 			if(chunkIds) {
/******/ 				priority = priority || 0;
/******/ 				for(var i = deferred.length; i > 0 && deferred[i - 1][2] > priority; i--) deferred[i] = deferred[i - 1];
/******/ 				deferred[i] = [chunkIds, fn, priority];
/******/ 				return;
/******/ 			}
/******/ 			var notFulfilled = Infinity;
/******/ 			for (var i = 0; i < deferred.length; i++) {
/******/ 				var [chunkIds, fn, priority] = deferred[i];
/******/ 				var fulfilled = true;
/******/ 				for (var j = 0; j < chunkIds.length; j++) {
/******/ 					if ((priority & 1 === 0 || notFulfilled >= priority) && Object.keys(__webpack_require__.O).every((key) => (__webpack_require__.O[key](chunkIds[j])))) {
/******/ 						chunkIds.splice(j--, 1);
/******/ 					} else {
/******/ 						fulfilled = false;
/******/ 						if(priority < notFulfilled) notFulfilled = priority;
/******/ 					}
/******/ 				}
/******/ 				if(fulfilled) {
/******/ 					deferred.splice(i--, 1)
/******/ 					result = fn();
/******/ 				}
/******/ 			}
/******/ 			return result;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => (module['default']) :
/******/ 				() => (module);
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/global */
/******/ 	(() => {
/******/ 		__webpack_require__.g = (function() {
/******/ 			if (typeof globalThis === 'object') return globalThis;
/******/ 			try {
/******/ 				return this || new Function('return this')();
/******/ 			} catch (e) {
/******/ 				if (typeof window === 'object') return window;
/******/ 			}
/******/ 		})();
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/publicPath */
/******/ 	(() => {
/******/ 		var scriptUrl;
/******/ 		if (__webpack_require__.g.importScripts) scriptUrl = __webpack_require__.g.location + "";
/******/ 		var document = __webpack_require__.g.document;
/******/ 		if (!scriptUrl && document) {
/******/ 			if (document.currentScript)
/******/ 				scriptUrl = document.currentScript.src
/******/ 			if (!scriptUrl) {
/******/ 				var scripts = document.getElementsByTagName("script");
/******/ 				if(scripts.length) scriptUrl = scripts[scripts.length - 1].src
/******/ 			}
/******/ 		}
/******/ 		// When supporting browsers where an automatic publicPath is not supported you must specify an output.publicPath manually via configuration
/******/ 		// or pass an empty string ("") and set the __webpack_public_path__ variable from your code to use your own logic.
/******/ 		if (!scriptUrl) throw new Error("Automatic publicPath is not supported in this browser");
/******/ 		scriptUrl = scriptUrl.replace(/#.*$/, "").replace(/\?.*$/, "").replace(/\/[^\/]+$/, "/");
/******/ 		__webpack_require__.p = scriptUrl;
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/jsonp chunk loading */
/******/ 	(() => {
/******/ 		// no baseURI
/******/ 		
/******/ 		// object to store loaded and loading chunks
/******/ 		// undefined = chunk not loaded, null = chunk preloaded/prefetched
/******/ 		// [resolve, reject, Promise] = chunk loading, 0 = chunk loaded
/******/ 		var installedChunks = {
/******/ 			351: 0
/******/ 		};
/******/ 		
/******/ 		// no chunk on demand loading
/******/ 		
/******/ 		// no prefetching
/******/ 		
/******/ 		// no preloaded
/******/ 		
/******/ 		// no HMR
/******/ 		
/******/ 		// no HMR manifest
/******/ 		
/******/ 		__webpack_require__.O.j = (chunkId) => (installedChunks[chunkId] === 0);
/******/ 		
/******/ 		// install a JSONP callback for chunk loading
/******/ 		var webpackJsonpCallback = (parentChunkLoadingFunction, data) => {
/******/ 			var [chunkIds, moreModules, runtime] = data;
/******/ 			// add "moreModules" to the modules object,
/******/ 			// then flag all "chunkIds" as loaded and fire callback
/******/ 			var moduleId, chunkId, i = 0;
/******/ 			for(moduleId in moreModules) {
/******/ 				if(__webpack_require__.o(moreModules, moduleId)) {
/******/ 					__webpack_require__.m[moduleId] = moreModules[moduleId];
/******/ 				}
/******/ 			}
/******/ 			if(runtime) var result = runtime(__webpack_require__);
/******/ 			if(parentChunkLoadingFunction) parentChunkLoadingFunction(data);
/******/ 			for(;i < chunkIds.length; i++) {
/******/ 				chunkId = chunkIds[i];
/******/ 				if(__webpack_require__.o(installedChunks, chunkId) && installedChunks[chunkId]) {
/******/ 					installedChunks[chunkId][0]();
/******/ 				}
/******/ 				installedChunks[chunkIds[i]] = 0;
/******/ 			}
/******/ 			return __webpack_require__.O(result);
/******/ 		}
/******/ 		
/******/ 		var chunkLoadingGlobal = self["webpackChunkage_gate"] = self["webpackChunkage_gate"] || [];
/******/ 		chunkLoadingGlobal.forEach(webpackJsonpCallback.bind(null, 0));
/******/ 		chunkLoadingGlobal.push = webpackJsonpCallback.bind(null, chunkLoadingGlobal.push.bind(chunkLoadingGlobal));
/******/ 	})();
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	
/******/ })()
;
//# sourceMappingURL=commons-8c01dc7583bc4f3b8855.min.js.map